"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[599],{81737:function(A){A.exports=function(){/*! *****************************************************************************
    Copyright (c) Microsoft Corporation.

    Permission to use, copy, modify, and/or distribute this software for any
    purpose with or without fee is hereby granted.

    THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
    REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
    AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
    INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
    LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
    OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
    PERFORMANCE OF THIS SOFTWARE.
    ***************************************************************************** */var A,e,t,r,B,n,s,o,i,Q,a,c,g,w,l,U,u,C,F,h,d,f,H,p,E=function(A,e){return(E=Object.setPrototypeOf||({__proto__:[]})instanceof Array&&function(A,e){A.__proto__=e}||function(A,e){for(var t in e)Object.prototype.hasOwnProperty.call(e,t)&&(A[t]=e[t])})(A,e)};function I(A,e){if("function"!=typeof e&&null!==e)throw TypeError("Class extends value "+String(e)+" is not a constructor or null");function t(){this.constructor=A}E(A,e),A.prototype=null===e?Object.create(e):(t.prototype=e.prototype,new t)}var y=function(){return(y=Object.assign||function(A){for(var e,t=1,r=arguments.length;t<r;t++)for(var B in e=arguments[t])Object.prototype.hasOwnProperty.call(e,B)&&(A[B]=e[B]);return A}).apply(this,arguments)};function K(A,e,t,r){return new(t||(t=Promise))(function(B,n){function s(A){try{i(r.next(A))}catch(A){n(A)}}function o(A){try{i(r.throw(A))}catch(A){n(A)}}function i(A){var e;A.done?B(A.value):((e=A.value)instanceof t?e:new t(function(A){A(e)})).then(s,o)}i((r=r.apply(A,e||[])).next())})}function m(A,e){var t,r,B,n,s={label:0,sent:function(){if(1&B[0])throw B[1];return B[1]},trys:[],ops:[]};return n={next:o(0),throw:o(1),return:o(2)},"function"==typeof Symbol&&(n[Symbol.iterator]=function(){return this}),n;function o(n){return function(o){return function(n){if(t)throw TypeError("Generator is already executing.");for(;s;)try{if(t=1,r&&(B=2&n[0]?r.return:n[0]?r.throw||((B=r.return)&&B.call(r),0):r.next)&&!(B=B.call(r,n[1])).done)return B;switch(r=0,B&&(n=[2&n[0],B.value]),n[0]){case 0:case 1:B=n;break;case 4:return s.label++,{value:n[1],done:!1};case 5:s.label++,r=n[1],n=[0];continue;case 7:n=s.ops.pop(),s.trys.pop();continue;default:if(!(B=(B=s.trys).length>0&&B[B.length-1])&&(6===n[0]||2===n[0])){s=0;continue}if(3===n[0]&&(!B||n[1]>B[0]&&n[1]<B[3])){s.label=n[1];break}if(6===n[0]&&s.label<B[1]){s.label=B[1],B=n;break}if(B&&s.label<B[2]){s.label=B[2],s.ops.push(n);break}B[2]&&s.ops.pop(),s.trys.pop();continue}n=e.call(A,s)}catch(A){n=[6,A],r=0}finally{t=B=0}if(5&n[0])throw n[1];return{value:n[0]?n[1]:void 0,done:!0}}([n,o])}}}function L(A,e,t){if(t||2==arguments.length)for(var r,B=0,n=e.length;B<n;B++)!r&&B in e||(r||(r=Array.prototype.slice.call(e,0,B)),r[B]=e[B]);return A.concat(r||e)}for(var b=function(){function A(A,e,t,r){this.left=A,this.top=e,this.width=t,this.height=r}return A.prototype.add=function(e,t,r,B){return new A(this.left+e,this.top+t,this.width+r,this.height+B)},A.fromClientRect=function(e,t){return new A(t.left+e.windowBounds.left,t.top+e.windowBounds.top,t.width,t.height)},A.fromDOMRectList=function(e,t){var r=Array.from(t).find(function(A){return 0!==A.width});return r?new A(r.left+e.windowBounds.left,r.top+e.windowBounds.top,r.width,r.height):A.EMPTY},A.EMPTY=new A(0,0,0,0),A}(),v=function(A,e){return b.fromClientRect(A,e.getBoundingClientRect())},D=function(A){var e=A.body,t=A.documentElement;if(!e||!t)throw Error("Unable to get document size");return new b(0,0,Math.max(Math.max(e.scrollWidth,t.scrollWidth),Math.max(e.offsetWidth,t.offsetWidth),Math.max(e.clientWidth,t.clientWidth)),Math.max(Math.max(e.scrollHeight,t.scrollHeight),Math.max(e.offsetHeight,t.offsetHeight),Math.max(e.clientHeight,t.clientHeight)))},x=function(A){for(var e=[],t=0,r=A.length;t<r;){var B=A.charCodeAt(t++);if(B>=55296&&B<=56319&&t<r){var n=A.charCodeAt(t++);(64512&n)==56320?e.push(((1023&B)<<10)+(1023&n)+65536):(e.push(B),t--)}else e.push(B)}return e},M=function(){for(var A=[],e=0;e<arguments.length;e++)A[e]=arguments[e];if(String.fromCodePoint)return String.fromCodePoint.apply(String,A);var t=A.length;if(!t)return"";for(var r=[],B=-1,n="";++B<t;){var s=A[B];s<=65535?r.push(s):(s-=65536,r.push((s>>10)+55296,s%1024+56320)),(B+1===t||r.length>16384)&&(n+=String.fromCharCode.apply(String,r),r.length=0)}return n},S="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",T="undefined"==typeof Uint8Array?[]:new Uint8Array(256),G=0;G<S.length;G++)T[S.charCodeAt(G)]=G;for(var O="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",V="undefined"==typeof Uint8Array?[]:new Uint8Array(256),k=0;k<O.length;k++)V[O.charCodeAt(k)]=k;for(var R=function(A,e,t){return A.slice?A.slice(e,t):new Uint16Array(Array.prototype.slice.call(A,e,t))},N=function(){function A(A,e,t,r,B,n){this.initialValue=A,this.errorValue=e,this.highStart=t,this.highValueIndex=r,this.index=B,this.data=n}return A.prototype.get=function(A){var e;if(A>=0){if(A<55296||A>56319&&A<=65535)return e=((e=this.index[A>>5])<<2)+(31&A),this.data[e];if(A<=65535)return e=((e=this.index[2048+(A-55296>>5)])<<2)+(31&A),this.data[e];if(A<this.highStart)return e=2080+(A>>11),e=this.index[e]+(A>>5&63),e=((e=this.index[e])<<2)+(31&A),this.data[e];if(A<=1114111)return this.data[this.highValueIndex]}return this.errorValue},A}(),P="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",X="undefined"==typeof Uint8Array?[]:new Uint8Array(256),J=0;J<P.length;J++)X[P.charCodeAt(J)]=J;var Y=[9001,65288],W=(e=Array.isArray(A=function(A){var e,t,r,B,n,s=.75*A.length,o=A.length,i=0;"="===A[A.length-1]&&(s--,"="===A[A.length-2]&&s--);var Q="undefined"!=typeof ArrayBuffer&&"undefined"!=typeof Uint8Array&&void 0!==Uint8Array.prototype.slice?new ArrayBuffer(s):Array(s),a=Array.isArray(Q)?Q:new Uint8Array(Q);for(e=0;e<o;e+=4)t=V[A.charCodeAt(e)],r=V[A.charCodeAt(e+1)],B=V[A.charCodeAt(e+2)],n=V[A.charCodeAt(e+3)],a[i++]=t<<2|r>>4,a[i++]=(15&r)<<4|B>>2,a[i++]=(3&B)<<6|63&n;return Q}(" "))?function(A){for(var e=A.length,t=[],r=0;r<e;r+=4)t.push(A[r+3]<<24|A[r+2]<<16|A[r+1]<<8|A[r]);return t}(A):new Uint32Array(A),r=R(t=Array.isArray(A)?function(A){for(var e=A.length,t=[],r=0;r<e;r+=2)t.push(A[r+1]<<8|A[r]);return t}(A):new Uint16Array(A),12,e[4]/2),s=2===e[5]?R(t,(24+e[4])/2):(B=Math.ceil((24+e[4])/4),e.slice?e.slice(B,n):new Uint32Array(Array.prototype.slice.call(e,B,n))),new N(e[0],e[1],e[2],e[3],r,s)),Z=[30,36],_=[1,2,3,5],q=[10,8],j=[27,26],z=_.concat(q),$=[38,39,40,34,35],AA=[15,13],Ae=function(A,e){void 0===e&&(e="strict");var t=[],r=[],B=[];return A.forEach(function(A,n){var s=W.get(A);if(s>50?(B.push(!0),s-=50):B.push(!1),-1!==["normal","auto","loose"].indexOf(e)&&-1!==[8208,8211,12316,12448].indexOf(A))return r.push(n),t.push(16);if(4===s||11===s){if(0===n)return r.push(n),t.push(30);var o=t[n-1];return -1===z.indexOf(o)?(r.push(r[n-1]),t.push(o)):(r.push(n),t.push(30))}return(r.push(n),31===s)?t.push("strict"===e?21:37):42===s||29===s?t.push(30):43===s?A>=131072&&A<=196605||A>=196608&&A<=262141?t.push(37):t.push(30):void t.push(s)}),[r,t,B]},At=function(A,e,t,r){var B=r[t];if(Array.isArray(A)?-1!==A.indexOf(B):A===B)for(var n=t;n<=r.length;){var s=r[++n];if(s===e)return!0;if(10!==s)break}if(10===B)for(var n=t;n>0;){var o=r[--n];if(Array.isArray(A)?-1!==A.indexOf(o):A===o)for(var i=t;i<=r.length;){var s=r[++i];if(s===e)return!0;if(10!==s)break}if(10!==o)break}return!1},Ar=function(A,e){for(var t=A;t>=0;){var r=e[t];if(10!==r)return r;t--}return 0},AB=function(A,e,t,r,B){if(0===t[r])return"\xd7";var n=r-1;if(Array.isArray(B)&&!0===B[n])return"\xd7";var s=n-1,o=n+1,i=e[n],Q=s>=0?e[s]:0,a=e[o];if(2===i&&3===a)return"\xd7";if(-1!==_.indexOf(i))return"!";if(-1!==_.indexOf(a)||-1!==q.indexOf(a))return"\xd7";if(8===Ar(n,e))return"\xf7";if(11===W.get(A[n])||(32===i||33===i)&&11===W.get(A[o])||7===i||7===a||9===i||-1===[10,13,15].indexOf(i)&&9===a||-1!==[17,18,19,24,28].indexOf(a)||22===Ar(n,e)||At(23,22,n,e)||At([17,18],21,n,e)||At(12,12,n,e))return"\xd7";if(10===i)return"\xf7";if(23===i||23===a)return"\xd7";if(16===a||16===i)return"\xf7";if(-1!==[13,15,21].indexOf(a)||14===i||36===Q&&-1!==AA.indexOf(i)||28===i&&36===a||20===a||-1!==Z.indexOf(a)&&25===i||-1!==Z.indexOf(i)&&25===a||27===i&&-1!==[37,32,33].indexOf(a)||-1!==[37,32,33].indexOf(i)&&26===a||-1!==Z.indexOf(i)&&-1!==j.indexOf(a)||-1!==j.indexOf(i)&&-1!==Z.indexOf(a)||-1!==[27,26].indexOf(i)&&(25===a||-1!==[22,15].indexOf(a)&&25===e[o+1])||-1!==[22,15].indexOf(i)&&25===a||25===i&&-1!==[25,28,24].indexOf(a))return"\xd7";if(-1!==[25,28,24,17,18].indexOf(a))for(var c=n;c>=0;){var g=e[c];if(25===g)return"\xd7";if(-1!==[28,24].indexOf(g))c--;else break}if(-1!==[27,26].indexOf(a))for(var c=-1!==[17,18].indexOf(i)?s:n;c>=0;){var g=e[c];if(25===g)return"\xd7";if(-1!==[28,24].indexOf(g))c--;else break}if(38===i&&-1!==[38,39,34,35].indexOf(a)||-1!==[39,34].indexOf(i)&&-1!==[39,40].indexOf(a)||-1!==[40,35].indexOf(i)&&40===a||-1!==$.indexOf(i)&&-1!==[20,26].indexOf(a)||-1!==$.indexOf(a)&&27===i||-1!==Z.indexOf(i)&&-1!==Z.indexOf(a)||24===i&&-1!==Z.indexOf(a)||-1!==Z.concat(25).indexOf(i)&&22===a&&-1===Y.indexOf(A[o])||-1!==Z.concat(25).indexOf(a)&&18===i)return"\xd7";if(41===i&&41===a){for(var w=t[n],l=1;w>0;)if(41===e[--w])l++;else break;if(l%2!=0)return"\xd7"}return 32===i&&33===a?"\xd7":"\xf7"},An=function(A,e){e||(e={lineBreak:"normal",wordBreak:"normal"});var t=Ae(A,e.lineBreak),r=t[0],B=t[1],n=t[2];return("break-all"===e.wordBreak||"break-word"===e.wordBreak)&&(B=B.map(function(A){return -1!==[25,30,42].indexOf(A)?37:A})),[r,B,"keep-all"===e.wordBreak?n.map(function(e,t){return e&&A[t]>=19968&&A[t]<=40959}):void 0]},As=function(){function A(A,e,t,r){this.codePoints=A,this.required="!"===e,this.start=t,this.end=r}return A.prototype.slice=function(){return M.apply(void 0,this.codePoints.slice(this.start,this.end))},A}(),Ao=function(A,e){var t=x(A),r=An(t,e),B=r[0],n=r[1],s=r[2],o=t.length,i=0,Q=0;return{next:function(){if(Q>=o)return{done:!0,value:null};for(var A="\xd7";Q<o&&"\xd7"===(A=AB(t,n,B,++Q,s)););if("\xd7"!==A||Q===o){var e=new As(t,A,i,Q);return i=Q,{value:e,done:!1}}return{done:!0,value:null}}}},Ai=function(A){return A>=48&&A<=57},AQ=function(A){return Ai(A)||A>=65&&A<=70||A>=97&&A<=102},Aa=function(A){return 10===A||9===A||32===A},Ac=function(A){var e;return(e=A)>=97&&e<=122||e>=65&&e<=90||A>=128||95===A},Ag=function(A){return Ac(A)||Ai(A)||45===A},Aw=function(A,e){return 92===A&&10!==e},Al=function(A,e,t){return 45===A?Ac(e)||Aw(e,t):!!(Ac(A)||92===A&&Aw(A,e))},AU=function(A,e,t){return 43===A||45===A?!!Ai(e)||46===e&&Ai(t):46===A?Ai(e):Ai(A)},Au=function(A){var e=0,t=1;(43===A[0]||45===A[e])&&(45===A[e]&&(t=-1),e++);for(var r=[];Ai(A[e]);)r.push(A[e++]);var B=r.length?parseInt(M.apply(void 0,r),10):0;46===A[e]&&e++;for(var n=[];Ai(A[e]);)n.push(A[e++]);var s=n.length,o=s?parseInt(M.apply(void 0,n),10):0;(69===A[e]||101===A[e])&&e++;var i=1;(43===A[e]||45===A[e])&&(45===A[e]&&(i=-1),e++);for(var Q=[];Ai(A[e]);)Q.push(A[e++]);return t*(B+o*Math.pow(10,-s))*Math.pow(10,i*(Q.length?parseInt(M.apply(void 0,Q),10):0))},AC={type:2},AF={type:3},Ah={type:4},Ad={type:13},Af={type:8},AH={type:21},Ap={type:9},AE={type:10},AI={type:11},Ay={type:12},AK={type:14},Am={type:23},AL={type:1},Ab={type:25},Av={type:24},AD={type:26},Ax={type:27},AM={type:28},AS={type:29},AT={type:31},AG={type:32},AO=function(){function A(){this._value=[]}return A.prototype.write=function(A){this._value=this._value.concat(x(A))},A.prototype.read=function(){for(var A=[],e=this.consumeToken();e!==AG;)A.push(e),e=this.consumeToken();return A},A.prototype.consumeToken=function(){var A=this.consumeCodePoint();switch(A){case 34:return this.consumeStringToken(34);case 35:var e=this.peekCodePoint(0),t=this.peekCodePoint(1),r=this.peekCodePoint(2);if(Ag(e)||Aw(t,r)){var B=Al(e,t,r)?2:1,n=this.consumeName();return{type:5,value:n,flags:B}}break;case 36:if(61===this.peekCodePoint(0))return this.consumeCodePoint(),Ad;break;case 39:return this.consumeStringToken(39);case 40:return AC;case 41:return AF;case 42:if(61===this.peekCodePoint(0))return this.consumeCodePoint(),AK;break;case 43:case 46:if(AU(A,this.peekCodePoint(0),this.peekCodePoint(1)))return this.reconsumeCodePoint(A),this.consumeNumericToken();break;case 44:return Ah;case 45:var s=this.peekCodePoint(0),o=this.peekCodePoint(1);if(AU(A,s,o))return this.reconsumeCodePoint(A),this.consumeNumericToken();if(Al(A,s,o))return this.reconsumeCodePoint(A),this.consumeIdentLikeToken();if(45===s&&62===o)return this.consumeCodePoint(),this.consumeCodePoint(),Av;break;case 47:if(42===this.peekCodePoint(0))for(this.consumeCodePoint();;){var i=this.consumeCodePoint();if(42===i&&47===(i=this.consumeCodePoint())||-1===i)return this.consumeToken()}break;case 58:return AD;case 59:return Ax;case 60:if(33===this.peekCodePoint(0)&&45===this.peekCodePoint(1)&&45===this.peekCodePoint(2))return this.consumeCodePoint(),this.consumeCodePoint(),Ab;break;case 64:if(Al(this.peekCodePoint(0),this.peekCodePoint(1),this.peekCodePoint(2))){var n=this.consumeName();return{type:7,value:n}}break;case 91:return AM;case 92:if(Aw(A,this.peekCodePoint(0)))return this.reconsumeCodePoint(A),this.consumeIdentLikeToken();break;case 93:return AS;case 61:if(61===this.peekCodePoint(0))return this.consumeCodePoint(),Af;break;case 123:return AI;case 125:return Ay;case 117:case 85:var Q=this.peekCodePoint(0),a=this.peekCodePoint(1);return 43===Q&&(AQ(a)||63===a)&&(this.consumeCodePoint(),this.consumeUnicodeRangeToken()),this.reconsumeCodePoint(A),this.consumeIdentLikeToken();case 124:if(61===this.peekCodePoint(0))return this.consumeCodePoint(),Ap;if(124===this.peekCodePoint(0))return this.consumeCodePoint(),AH;break;case 126:if(61===this.peekCodePoint(0))return this.consumeCodePoint(),AE;break;case -1:return AG}return Aa(A)?(this.consumeWhiteSpace(),AT):Ai(A)?(this.reconsumeCodePoint(A),this.consumeNumericToken()):Ac(A)?(this.reconsumeCodePoint(A),this.consumeIdentLikeToken()):{type:6,value:M(A)}},A.prototype.consumeCodePoint=function(){var A=this._value.shift();return void 0===A?-1:A},A.prototype.reconsumeCodePoint=function(A){this._value.unshift(A)},A.prototype.peekCodePoint=function(A){return A>=this._value.length?-1:this._value[A]},A.prototype.consumeUnicodeRangeToken=function(){for(var A=[],e=this.consumeCodePoint();AQ(e)&&A.length<6;)A.push(e),e=this.consumeCodePoint();for(var t=!1;63===e&&A.length<6;)A.push(e),e=this.consumeCodePoint(),t=!0;if(t){var r=parseInt(M.apply(void 0,A.map(function(A){return 63===A?48:A})),16),B=parseInt(M.apply(void 0,A.map(function(A){return 63===A?70:A})),16);return{type:30,start:r,end:B}}var n=parseInt(M.apply(void 0,A),16);if(!(45===this.peekCodePoint(0)&&AQ(this.peekCodePoint(1))))return{type:30,start:n,end:n};this.consumeCodePoint(),e=this.consumeCodePoint();for(var s=[];AQ(e)&&s.length<6;)s.push(e),e=this.consumeCodePoint();var B=parseInt(M.apply(void 0,s),16);return{type:30,start:n,end:B}},A.prototype.consumeIdentLikeToken=function(){var A=this.consumeName();return"url"===A.toLowerCase()&&40===this.peekCodePoint(0)?(this.consumeCodePoint(),this.consumeUrlToken()):40===this.peekCodePoint(0)?(this.consumeCodePoint(),{type:19,value:A}):{type:20,value:A}},A.prototype.consumeUrlToken=function(){var A=[];if(this.consumeWhiteSpace(),-1===this.peekCodePoint(0))return{type:22,value:""};var e=this.peekCodePoint(0);if(39===e||34===e){var t=this.consumeStringToken(this.consumeCodePoint());return 0===t.type&&(this.consumeWhiteSpace(),-1===this.peekCodePoint(0)||41===this.peekCodePoint(0))?(this.consumeCodePoint(),{type:22,value:t.value}):(this.consumeBadUrlRemnants(),Am)}for(;;){var r,B=this.consumeCodePoint();if(-1===B||41===B)return{type:22,value:M.apply(void 0,A)};if(Aa(B)){if(this.consumeWhiteSpace(),-1===this.peekCodePoint(0)||41===this.peekCodePoint(0))return this.consumeCodePoint(),{type:22,value:M.apply(void 0,A)};return this.consumeBadUrlRemnants(),Am}if(34===B||39===B||40===B||(r=B)>=0&&r<=8||11===r||r>=14&&r<=31||127===r)return this.consumeBadUrlRemnants(),Am;if(92===B){if(!Aw(B,this.peekCodePoint(0)))return this.consumeBadUrlRemnants(),Am;A.push(this.consumeEscapedCodePoint())}else A.push(B)}},A.prototype.consumeWhiteSpace=function(){for(;Aa(this.peekCodePoint(0));)this.consumeCodePoint()},A.prototype.consumeBadUrlRemnants=function(){for(;;){var A=this.consumeCodePoint();if(41===A||-1===A)return;Aw(A,this.peekCodePoint(0))&&this.consumeEscapedCodePoint()}},A.prototype.consumeStringSlice=function(A){for(var e="";A>0;){var t=Math.min(5e4,A);e+=M.apply(void 0,this._value.splice(0,t)),A-=t}return this._value.shift(),e},A.prototype.consumeStringToken=function(A){for(var e="",t=0;;){var r=this._value[t];if(-1===r||void 0===r||r===A)return{type:0,value:e+=this.consumeStringSlice(t)};if(10===r)return this._value.splice(0,t),AL;if(92===r){var B=this._value[t+1];-1!==B&&void 0!==B&&(10===B?(e+=this.consumeStringSlice(t),t=-1,this._value.shift()):Aw(r,B)&&(e+=this.consumeStringSlice(t)+M(this.consumeEscapedCodePoint()),t=-1))}t++}},A.prototype.consumeNumber=function(){var A=[],e=4,t=this.peekCodePoint(0);for((43===t||45===t)&&A.push(this.consumeCodePoint());Ai(this.peekCodePoint(0));)A.push(this.consumeCodePoint());t=this.peekCodePoint(0);var r=this.peekCodePoint(1);if(46===t&&Ai(r))for(A.push(this.consumeCodePoint(),this.consumeCodePoint()),e=8;Ai(this.peekCodePoint(0));)A.push(this.consumeCodePoint());t=this.peekCodePoint(0),r=this.peekCodePoint(1);var B=this.peekCodePoint(2);if((69===t||101===t)&&((43===r||45===r)&&Ai(B)||Ai(r)))for(A.push(this.consumeCodePoint(),this.consumeCodePoint()),e=8;Ai(this.peekCodePoint(0));)A.push(this.consumeCodePoint());return[Au(A),e]},A.prototype.consumeNumericToken=function(){var A=this.consumeNumber(),e=A[0],t=A[1],r=this.peekCodePoint(0);return Al(r,this.peekCodePoint(1),this.peekCodePoint(2))?{type:15,number:e,flags:t,unit:this.consumeName()}:37===r?(this.consumeCodePoint(),{type:16,number:e,flags:t}):{type:17,number:e,flags:t}},A.prototype.consumeEscapedCodePoint=function(){var A=this.consumeCodePoint();if(AQ(A)){for(var e=M(A);AQ(this.peekCodePoint(0))&&e.length<6;)e+=M(this.consumeCodePoint());Aa(this.peekCodePoint(0))&&this.consumeCodePoint();var t=parseInt(e,16);return 0===t||t>=55296&&t<=57343||t>1114111?65533:t}return -1===A?65533:A},A.prototype.consumeName=function(){for(var A="";;){var e=this.consumeCodePoint();if(Ag(e))A+=M(e);else{if(!Aw(e,this.peekCodePoint(0)))return this.reconsumeCodePoint(e),A;A+=M(this.consumeEscapedCodePoint())}}},A}(),AV=function(){function A(A){this._tokens=A}return A.create=function(e){var t=new AO;return t.write(e),new A(t.read())},A.parseValue=function(e){return A.create(e).parseComponentValue()},A.parseValues=function(e){return A.create(e).parseComponentValues()},A.prototype.parseComponentValue=function(){for(var A=this.consumeToken();31===A.type;)A=this.consumeToken();if(32===A.type)throw SyntaxError("Error parsing CSS component value, unexpected EOF");this.reconsumeToken(A);var e=this.consumeComponentValue();do A=this.consumeToken();while(31===A.type);if(32===A.type)return e;throw SyntaxError("Error parsing CSS component value, multiple values found when expecting only one")},A.prototype.parseComponentValues=function(){for(var A=[];;){var e=this.consumeComponentValue();if(32===e.type)return A;A.push(e),A.push()}},A.prototype.consumeComponentValue=function(){var A=this.consumeToken();switch(A.type){case 11:case 28:case 2:return this.consumeSimpleBlock(A.type);case 19:return this.consumeFunction(A)}return A},A.prototype.consumeSimpleBlock=function(A){for(var e={type:A,values:[]},t=this.consumeToken();;){if(32===t.type||AZ(t,A))return e;this.reconsumeToken(t),e.values.push(this.consumeComponentValue()),t=this.consumeToken()}},A.prototype.consumeFunction=function(A){for(var e={name:A.value,values:[],type:18};;){var t=this.consumeToken();if(32===t.type||3===t.type)return e;this.reconsumeToken(t),e.values.push(this.consumeComponentValue())}},A.prototype.consumeToken=function(){var A=this._tokens.shift();return void 0===A?AG:A},A.prototype.reconsumeToken=function(A){this._tokens.unshift(A)},A}(),Ak=function(A){return 15===A.type},AR=function(A){return 17===A.type},AN=function(A){return 20===A.type},AP=function(A){return 0===A.type},AX=function(A,e){return AN(A)&&A.value===e},AJ=function(A){return 31!==A.type},AY=function(A){return 31!==A.type&&4!==A.type},AW=function(A){var e=[],t=[];return A.forEach(function(A){if(4===A.type){if(0===t.length)throw Error("Error parsing function args, zero tokens for arg");e.push(t),t=[];return}31!==A.type&&t.push(A)}),t.length&&e.push(t),e},AZ=function(A,e){return 11===e&&12===A.type||28===e&&29===A.type||2===e&&3===A.type},A_=function(A){return 17===A.type||15===A.type},Aq=function(A){return 16===A.type||A_(A)},Aj=function(A){return A.length>1?[A[0],A[1]]:[A[0]]},Az={type:17,number:0,flags:4},A$={type:16,number:50,flags:4},A0={type:16,number:100,flags:4},A4=function(A,e,t){var r=A[0],B=A[1];return[A1(r,e),A1(void 0!==B?B:r,t)]},A1=function(A,e){if(16===A.type)return A.number/100*e;if(Ak(A))switch(A.unit){case"rem":case"em":return 16*A.number}return A.number},A2="grad",A3="turn",A5={name:"angle",parse:function(A,e){if(15===e.type)switch(e.unit){case"deg":return Math.PI*e.number/180;case A2:return Math.PI/200*e.number;case"rad":return e.number;case A3:return 2*Math.PI*e.number}throw Error("Unsupported angle type")}},A6=function(A){return 15===A.type&&("deg"===A.unit||A.unit===A2||"rad"===A.unit||A.unit===A3)},A8=function(A){switch(A.filter(AN).map(function(A){return A.value}).join(" ")){case"to bottom right":case"to right bottom":case"left top":case"top left":return[Az,Az];case"to top":case"bottom":return A9(0);case"to bottom left":case"to left bottom":case"right top":case"top right":return[Az,A0];case"to right":case"left":return A9(90);case"to top left":case"to left top":case"right bottom":case"bottom right":return[A0,A0];case"to bottom":case"top":return A9(180);case"to top right":case"to right top":case"left bottom":case"bottom left":return[A0,Az];case"to left":case"right":return A9(270)}return 0},A9=function(A){return Math.PI*A/180},A7={name:"color",parse:function(A,e){if(18===e.type){var t=eo[e.name];if(void 0===t)throw Error('Attempting to parse an unsupported color function "'+e.name+'"');return t(A,e.values)}if(5===e.type){if(3===e.value.length){var r=e.value.substring(0,1),B=e.value.substring(1,2),n=e.value.substring(2,3);return et(parseInt(r+r,16),parseInt(B+B,16),parseInt(n+n,16),1)}if(4===e.value.length){var r=e.value.substring(0,1),B=e.value.substring(1,2),n=e.value.substring(2,3),s=e.value.substring(3,4);return et(parseInt(r+r,16),parseInt(B+B,16),parseInt(n+n,16),parseInt(s+s,16)/255)}if(6===e.value.length){var r=e.value.substring(0,2),B=e.value.substring(2,4),n=e.value.substring(4,6);return et(parseInt(r,16),parseInt(B,16),parseInt(n,16),1)}if(8===e.value.length){var r=e.value.substring(0,2),B=e.value.substring(2,4),n=e.value.substring(4,6),s=e.value.substring(6,8);return et(parseInt(r,16),parseInt(B,16),parseInt(n,16),parseInt(s,16)/255)}}if(20===e.type){var o=eQ[e.value.toUpperCase()];if(void 0!==o)return o}return eQ.TRANSPARENT}},eA=function(A){return(255&A)==0},ee=function(A){var e=255&A,t=255&A>>8,r=255&A>>16,B=255&A>>24;return e<255?"rgba("+B+","+r+","+t+","+e/255+")":"rgb("+B+","+r+","+t+")"},et=function(A,e,t,r){return(A<<24|e<<16|t<<8|Math.round(255*r)<<0)>>>0},er=function(A,e){if(17===A.type)return A.number;if(16===A.type){var t=3===e?1:255;return 3===e?A.number/100*t:Math.round(A.number/100*t)}return 0},eB=function(A,e){var t=e.filter(AY);if(3===t.length){var r=t.map(er),B=r[0],n=r[1],s=r[2];return et(B,n,s,1)}if(4===t.length){var o=t.map(er),B=o[0],n=o[1],s=o[2];return et(B,n,s,o[3])}return 0};function en(A,e,t){return(t<0&&(t+=1),t>=1&&(t-=1),t<1/6)?(e-A)*t*6+A:t<.5?e:t<2/3?(e-A)*6*(2/3-t)+A:A}var es=function(A,e){var t=e.filter(AY),r=t[0],B=t[1],n=t[2],s=t[3],o=(17===r.type?A9(r.number):A5.parse(A,r))/(2*Math.PI),i=Aq(B)?B.number/100:0,Q=Aq(n)?n.number/100:0,a=void 0!==s&&Aq(s)?A1(s,1):1;if(0===i)return et(255*Q,255*Q,255*Q,1);var c=Q<=.5?Q*(i+1):Q+i-Q*i,g=2*Q-c;return et(255*en(g,c,o+1/3),255*en(g,c,o),255*en(g,c,o-1/3),a)},eo={hsl:es,hsla:es,rgb:eB,rgba:eB},ei=function(A,e){return A7.parse(A,AV.create(e).parseComponentValue())},eQ={ALICEBLUE:4042850303,ANTIQUEWHITE:4209760255,AQUA:16777215,AQUAMARINE:2147472639,AZURE:4043309055,BEIGE:4126530815,BISQUE:4293182719,BLACK:255,BLANCHEDALMOND:4293643775,BLUE:65535,BLUEVIOLET:2318131967,BROWN:2771004159,BURLYWOOD:3736635391,CADETBLUE:1604231423,CHARTREUSE:2147418367,CHOCOLATE:3530104575,CORAL:4286533887,CORNFLOWERBLUE:1687547391,CORNSILK:4294499583,CRIMSON:3692313855,CYAN:16777215,DARKBLUE:35839,DARKCYAN:9145343,DARKGOLDENROD:3095837695,DARKGRAY:2846468607,DARKGREEN:6553855,DARKGREY:2846468607,DARKKHAKI:3182914559,DARKMAGENTA:2332068863,DARKOLIVEGREEN:1433087999,DARKORANGE:4287365375,DARKORCHID:2570243327,DARKRED:2332033279,DARKSALMON:3918953215,DARKSEAGREEN:2411499519,DARKSLATEBLUE:1211993087,DARKSLATEGRAY:793726975,DARKSLATEGREY:793726975,DARKTURQUOISE:13554175,DARKVIOLET:2483082239,DEEPPINK:4279538687,DEEPSKYBLUE:12582911,DIMGRAY:1768516095,DIMGREY:1768516095,DODGERBLUE:512819199,FIREBRICK:2988581631,FLORALWHITE:4294635775,FORESTGREEN:579543807,FUCHSIA:4278255615,GAINSBORO:3705462015,GHOSTWHITE:4177068031,GOLD:4292280575,GOLDENROD:3668254975,GRAY:2155905279,GREEN:8388863,GREENYELLOW:2919182335,GREY:2155905279,HONEYDEW:4043305215,HOTPINK:4285117695,INDIANRED:3445382399,INDIGO:1258324735,IVORY:4294963455,KHAKI:4041641215,LAVENDER:3873897215,LAVENDERBLUSH:4293981695,LAWNGREEN:2096890111,LEMONCHIFFON:4294626815,LIGHTBLUE:2916673279,LIGHTCORAL:4034953471,LIGHTCYAN:3774873599,LIGHTGOLDENRODYELLOW:4210742015,LIGHTGRAY:3553874943,LIGHTGREEN:2431553791,LIGHTGREY:3553874943,LIGHTPINK:4290167295,LIGHTSALMON:4288707327,LIGHTSEAGREEN:548580095,LIGHTSKYBLUE:2278488831,LIGHTSLATEGRAY:2005441023,LIGHTSLATEGREY:2005441023,LIGHTSTEELBLUE:2965692159,LIGHTYELLOW:4294959359,LIME:16711935,LIMEGREEN:852308735,LINEN:4210091775,MAGENTA:4278255615,MAROON:2147483903,MEDIUMAQUAMARINE:1724754687,MEDIUMBLUE:52735,MEDIUMORCHID:3126187007,MEDIUMPURPLE:2473647103,MEDIUMSEAGREEN:1018393087,MEDIUMSLATEBLUE:2070474495,MEDIUMSPRINGGREEN:16423679,MEDIUMTURQUOISE:1221709055,MEDIUMVIOLETRED:3340076543,MIDNIGHTBLUE:421097727,MINTCREAM:4127193855,MISTYROSE:4293190143,MOCCASIN:4293178879,NAVAJOWHITE:4292783615,NAVY:33023,OLDLACE:4260751103,OLIVE:2155872511,OLIVEDRAB:1804477439,ORANGE:4289003775,ORANGERED:4282712319,ORCHID:3664828159,PALEGOLDENROD:4008225535,PALEGREEN:2566625535,PALETURQUOISE:2951671551,PALEVIOLETRED:3681588223,PAPAYAWHIP:4293907967,PEACHPUFF:4292524543,PERU:3448061951,PINK:4290825215,PLUM:3718307327,POWDERBLUE:2967529215,PURPLE:2147516671,REBECCAPURPLE:1714657791,RED:4278190335,ROSYBROWN:3163525119,ROYALBLUE:1097458175,SADDLEBROWN:2336560127,SALMON:4202722047,SANDYBROWN:4104413439,SEAGREEN:780883967,SEASHELL:4294307583,SIENNA:2689740287,SILVER:3233857791,SKYBLUE:2278484991,SLATEBLUE:1784335871,SLATEGRAY:1887473919,SLATEGREY:1887473919,SNOW:4294638335,SPRINGGREEN:16744447,STEELBLUE:1182971135,TAN:3535047935,TEAL:8421631,THISTLE:3636451583,TOMATO:4284696575,TRANSPARENT:0,TURQUOISE:1088475391,VIOLET:4001558271,WHEAT:4125012991,WHITE:4294967295,WHITESMOKE:4126537215,YELLOW:4294902015,YELLOWGREEN:2597139199},ea={name:"background-clip",initialValue:"border-box",prefix:!1,type:1,parse:function(A,e){return e.map(function(A){if(AN(A))switch(A.value){case"padding-box":return 1;case"content-box":return 2}return 0})}},ec={name:"background-color",initialValue:"transparent",prefix:!1,type:3,format:"color"},eg=function(A,e){var t=A7.parse(A,e[0]),r=e[1];return r&&Aq(r)?{color:t,stop:r}:{color:t,stop:null}},ew=function(A,e){var t=A[0],r=A[A.length-1];null===t.stop&&(t.stop=Az),null===r.stop&&(r.stop=A0);for(var B=[],n=0,s=0;s<A.length;s++){var o=A[s].stop;if(null!==o){var i=A1(o,e);i>n?B.push(i):B.push(n),n=i}else B.push(null)}for(var Q=null,s=0;s<B.length;s++){var a=B[s];if(null===a)null===Q&&(Q=s);else if(null!==Q){for(var c=s-Q,g=(a-B[Q-1])/(c+1),w=1;w<=c;w++)B[Q+w-1]=g*w;Q=null}}return A.map(function(A,t){return{color:A.color,stop:Math.max(Math.min(1,B[t]/e),0)}})},el=function(A,e,t){var r=e/2,B=t/2,n=A1(A[0],e)-r;return(Math.atan2(B-A1(A[1],t),n)+2*Math.PI)%(2*Math.PI)},eU=function(A,e,t){var r="number"==typeof A?A:el(A,e,t),B=Math.abs(e*Math.sin(r))+Math.abs(t*Math.cos(r)),n=e/2,s=t/2,o=B/2,i=Math.sin(r-Math.PI/2)*o,Q=Math.cos(r-Math.PI/2)*o;return[B,n-Q,n+Q,s-i,s+i]},eu=function(A,e){return Math.sqrt(A*A+e*e)},eC=function(A,e,t,r,B){return[[0,0],[0,e],[A,0],[A,e]].reduce(function(A,e){var n=eu(t-e[0],r-e[1]);return(B?n<A.optimumDistance:n>A.optimumDistance)?{optimumCorner:e,optimumDistance:n}:A},{optimumDistance:B?1/0:-1/0,optimumCorner:null}).optimumCorner},eF=function(A,e,t,r,B){var n=0,s=0;switch(A.size){case 0:0===A.shape?n=s=Math.min(Math.abs(e),Math.abs(e-r),Math.abs(t),Math.abs(t-B)):1===A.shape&&(n=Math.min(Math.abs(e),Math.abs(e-r)),s=Math.min(Math.abs(t),Math.abs(t-B)));break;case 2:if(0===A.shape)n=s=Math.min(eu(e,t),eu(e,t-B),eu(e-r,t),eu(e-r,t-B));else if(1===A.shape){var o=Math.min(Math.abs(t),Math.abs(t-B))/Math.min(Math.abs(e),Math.abs(e-r)),i=eC(r,B,e,t,!0),Q=i[0],a=i[1];n=eu(Q-e,(a-t)/o),s=o*n}break;case 1:0===A.shape?n=s=Math.max(Math.abs(e),Math.abs(e-r),Math.abs(t),Math.abs(t-B)):1===A.shape&&(n=Math.max(Math.abs(e),Math.abs(e-r)),s=Math.max(Math.abs(t),Math.abs(t-B)));break;case 3:if(0===A.shape)n=s=Math.max(eu(e,t),eu(e,t-B),eu(e-r,t),eu(e-r,t-B));else if(1===A.shape){var o=Math.max(Math.abs(t),Math.abs(t-B))/Math.max(Math.abs(e),Math.abs(e-r)),c=eC(r,B,e,t,!1),Q=c[0],a=c[1];n=eu(Q-e,(a-t)/o),s=o*n}}return Array.isArray(A.size)&&(n=A1(A.size[0],r),s=2===A.size.length?A1(A.size[1],B):n),[n,s]},eh=function(A,e){var t=A9(180),r=[];return AW(e).forEach(function(e,B){if(0===B){var n=e[0];if(20===n.type&&-1!==["top","left","right","bottom"].indexOf(n.value)){t=A8(e);return}if(A6(n)){t=(A5.parse(A,n)+A9(270))%A9(360);return}}var s=eg(A,e);r.push(s)}),{angle:t,stops:r,type:1}},ed="closest-side",ef="farthest-side",eH="closest-corner",ep="farthest-corner",eE="circle",eI="ellipse",ey="cover",eK="contain",em=function(A,e){var t=0,r=3,B=[],n=[];return AW(e).forEach(function(e,s){var o=!0;if(0===s?o=e.reduce(function(A,e){if(AN(e))switch(e.value){case"center":return n.push(A$),!1;case"top":case"left":return n.push(Az),!1;case"right":case"bottom":return n.push(A0),!1}else if(Aq(e)||A_(e))return n.push(e),!1;return A},o):1===s&&(o=e.reduce(function(A,e){if(AN(e))switch(e.value){case eE:return t=0,!1;case eI:return t=1,!1;case eK:case ed:return r=0,!1;case ef:return r=1,!1;case eH:return r=2,!1;case ey:case ep:return r=3,!1}else if(A_(e)||Aq(e))return Array.isArray(r)||(r=[]),r.push(e),!1;return A},o)),o){var i=eg(A,e);B.push(i)}}),{size:r,shape:t,stops:B,position:n,type:2}},eL={name:"image",parse:function(A,e){if(22===e.type){var t={url:e.value,type:0};return A.cache.addImage(e.value),t}if(18===e.type){var r=eb[e.name];if(void 0===r)throw Error('Attempting to parse an unsupported image function "'+e.name+'"');return r(A,e.values)}throw Error("Unsupported image type "+e.type)}},eb={"linear-gradient":function(A,e){var t=A9(180),r=[];return AW(e).forEach(function(e,B){if(0===B){var n=e[0];if(20===n.type&&"to"===n.value){t=A8(e);return}if(A6(n)){t=A5.parse(A,n);return}}var s=eg(A,e);r.push(s)}),{angle:t,stops:r,type:1}},"-moz-linear-gradient":eh,"-ms-linear-gradient":eh,"-o-linear-gradient":eh,"-webkit-linear-gradient":eh,"radial-gradient":function(A,e){var t=0,r=3,B=[],n=[];return AW(e).forEach(function(e,s){var o=!0;if(0===s){var i=!1;o=e.reduce(function(A,e){if(i){if(AN(e))switch(e.value){case"center":n.push(A$);break;case"top":case"left":n.push(Az);break;case"right":case"bottom":n.push(A0)}else(Aq(e)||A_(e))&&n.push(e)}else if(AN(e))switch(e.value){case eE:return t=0,!1;case eI:return t=1,!1;case"at":return i=!0,!1;case ed:return r=0,!1;case ey:case ef:return r=1,!1;case eK:case eH:return r=2,!1;case ep:return r=3,!1}else if(A_(e)||Aq(e))return Array.isArray(r)||(r=[]),r.push(e),!1;return A},o)}if(o){var Q=eg(A,e);B.push(Q)}}),{size:r,shape:t,stops:B,position:n,type:2}},"-moz-radial-gradient":em,"-ms-radial-gradient":em,"-o-radial-gradient":em,"-webkit-radial-gradient":em,"-webkit-gradient":function(A,e){var t=A9(180),r=[],B=1;return AW(e).forEach(function(e,t){var n=e[0];if(0===t){if(AN(n)&&"linear"===n.value){B=1;return}if(AN(n)&&"radial"===n.value){B=2;return}}if(18===n.type){if("from"===n.name){var s=A7.parse(A,n.values[0]);r.push({stop:Az,color:s})}else if("to"===n.name){var s=A7.parse(A,n.values[0]);r.push({stop:A0,color:s})}else if("color-stop"===n.name){var o=n.values.filter(AY);if(2===o.length){var s=A7.parse(A,o[1]),i=o[0];AR(i)&&r.push({stop:{type:16,number:100*i.number,flags:i.flags},color:s})}}}}),1===B?{angle:(t+A9(180))%A9(360),stops:r,type:B}:{size:3,shape:0,stops:r,position:[],type:B}}},ev={name:"background-image",initialValue:"none",type:1,prefix:!1,parse:function(A,e){if(0===e.length)return[];var t=e[0];return 20===t.type&&"none"===t.value?[]:e.filter(function(A){var e;return AY(A)&&!(20===(e=A).type&&"none"===e.value)&&(18!==e.type||!!eb[e.name])}).map(function(e){return eL.parse(A,e)})}},eD={name:"background-origin",initialValue:"border-box",prefix:!1,type:1,parse:function(A,e){return e.map(function(A){if(AN(A))switch(A.value){case"padding-box":return 1;case"content-box":return 2}return 0})}},ex={name:"background-position",initialValue:"0% 0%",type:1,prefix:!1,parse:function(A,e){return AW(e).map(function(A){return A.filter(Aq)}).map(Aj)}},eM={name:"background-repeat",initialValue:"repeat",prefix:!1,type:1,parse:function(A,e){return AW(e).map(function(A){return A.filter(AN).map(function(A){return A.value}).join(" ")}).map(eS)}},eS=function(A){switch(A){case"no-repeat":return 1;case"repeat-x":case"repeat no-repeat":return 2;case"repeat-y":case"no-repeat repeat":return 3;default:return 0}};(o=h||(h={})).AUTO="auto",o.CONTAIN="contain",o.COVER="cover";var eT={name:"background-size",initialValue:"0",prefix:!1,type:1,parse:function(A,e){return AW(e).map(function(A){return A.filter(eG)})}},eG=function(A){return AN(A)||Aq(A)},eO=function(A){return{name:"border-"+A+"-color",initialValue:"transparent",prefix:!1,type:3,format:"color"}},eV=eO("top"),ek=eO("right"),eR=eO("bottom"),eN=eO("left"),eP=function(A){return{name:"border-radius-"+A,initialValue:"0 0",prefix:!1,type:1,parse:function(A,e){return Aj(e.filter(Aq))}}},eX=eP("top-left"),eJ=eP("top-right"),eY=eP("bottom-right"),eW=eP("bottom-left"),eZ=function(A){return{name:"border-"+A+"-style",initialValue:"solid",prefix:!1,type:2,parse:function(A,e){switch(e){case"none":return 0;case"dashed":return 2;case"dotted":return 3;case"double":return 4}return 1}}},e_=eZ("top"),eq=eZ("right"),ej=eZ("bottom"),ez=eZ("left"),e$=function(A){return{name:"border-"+A+"-width",initialValue:"0",type:0,prefix:!1,parse:function(A,e){return Ak(e)?e.number:0}}},e0=e$("top"),e4=e$("right"),e1=e$("bottom"),e2=e$("left"),e3={name:"color",initialValue:"transparent",prefix:!1,type:3,format:"color"},e5={name:"direction",initialValue:"ltr",prefix:!1,type:2,parse:function(A,e){return"rtl"===e?1:0}},e6={name:"display",initialValue:"inline-block",prefix:!1,type:1,parse:function(A,e){return e.filter(AN).reduce(function(A,e){return A|e8(e.value)},0)}},e8=function(A){switch(A){case"block":case"-webkit-box":return 2;case"inline":return 4;case"run-in":return 8;case"flow":return 16;case"flow-root":return 32;case"table":return 64;case"flex":case"-webkit-flex":return 128;case"grid":case"-ms-grid":return 256;case"ruby":return 512;case"subgrid":return 1024;case"list-item":return 2048;case"table-row-group":return 4096;case"table-header-group":return 8192;case"table-footer-group":return 16384;case"table-row":return 32768;case"table-cell":return 65536;case"table-column-group":return 131072;case"table-column":return 262144;case"table-caption":return 524288;case"ruby-base":return 1048576;case"ruby-text":return 2097152;case"ruby-base-container":return 4194304;case"ruby-text-container":return 8388608;case"contents":return 16777216;case"inline-block":return 33554432;case"inline-list-item":return 67108864;case"inline-table":return 134217728;case"inline-flex":return 268435456;case"inline-grid":return 536870912}return 0},e9={name:"float",initialValue:"none",prefix:!1,type:2,parse:function(A,e){switch(e){case"left":return 1;case"right":return 2;case"inline-start":return 3;case"inline-end":return 4}return 0}},e7={name:"letter-spacing",initialValue:"0",prefix:!1,type:0,parse:function(A,e){return 20===e.type&&"normal"===e.value?0:17===e.type||15===e.type?e.number:0}};(i=d||(d={})).NORMAL="normal",i.STRICT="strict";var tA={name:"line-break",initialValue:"normal",prefix:!1,type:2,parse:function(A,e){return"strict"===e?d.STRICT:d.NORMAL}},te={name:"line-height",initialValue:"normal",prefix:!1,type:4},tt=function(A,e){return AN(A)&&"normal"===A.value?1.2*e:17===A.type?e*A.number:Aq(A)?A1(A,e):e},tr={name:"list-style-image",initialValue:"none",type:0,prefix:!1,parse:function(A,e){return 20===e.type&&"none"===e.value?null:eL.parse(A,e)}},tB={name:"list-style-position",initialValue:"outside",prefix:!1,type:2,parse:function(A,e){return"inside"===e?0:1}},tn={name:"list-style-type",initialValue:"none",prefix:!1,type:2,parse:function(A,e){switch(e){case"disc":return 0;case"circle":return 1;case"square":return 2;case"decimal":return 3;case"cjk-decimal":return 4;case"decimal-leading-zero":return 5;case"lower-roman":return 6;case"upper-roman":return 7;case"lower-greek":return 8;case"lower-alpha":return 9;case"upper-alpha":return 10;case"arabic-indic":return 11;case"armenian":return 12;case"bengali":return 13;case"cambodian":return 14;case"cjk-earthly-branch":return 15;case"cjk-heavenly-stem":return 16;case"cjk-ideographic":return 17;case"devanagari":return 18;case"ethiopic-numeric":return 19;case"georgian":return 20;case"gujarati":return 21;case"gurmukhi":case"hebrew":return 22;case"hiragana":return 23;case"hiragana-iroha":return 24;case"japanese-formal":return 25;case"japanese-informal":return 26;case"kannada":return 27;case"katakana":return 28;case"katakana-iroha":return 29;case"khmer":return 30;case"korean-hangul-formal":return 31;case"korean-hanja-formal":return 32;case"korean-hanja-informal":return 33;case"lao":return 34;case"lower-armenian":return 35;case"malayalam":return 36;case"mongolian":return 37;case"myanmar":return 38;case"oriya":return 39;case"persian":return 40;case"simp-chinese-formal":return 41;case"simp-chinese-informal":return 42;case"tamil":return 43;case"telugu":return 44;case"thai":return 45;case"tibetan":return 46;case"trad-chinese-formal":return 47;case"trad-chinese-informal":return 48;case"upper-armenian":return 49;case"disclosure-open":return 50;case"disclosure-closed":return 51;default:return -1}}},ts=function(A){return{name:"margin-"+A,initialValue:"0",prefix:!1,type:4}},to=ts("top"),ti=ts("right"),tQ=ts("bottom"),ta=ts("left"),tc={name:"overflow",initialValue:"visible",prefix:!1,type:1,parse:function(A,e){return e.filter(AN).map(function(A){switch(A.value){case"hidden":return 1;case"scroll":return 2;case"clip":return 3;case"auto":return 4;default:return 0}})}},tg={name:"overflow-wrap",initialValue:"normal",prefix:!1,type:2,parse:function(A,e){return"break-word"===e?"break-word":"normal"}},tw=function(A){return{name:"padding-"+A,initialValue:"0",prefix:!1,type:3,format:"length-percentage"}},tl=tw("top"),tU=tw("right"),tu=tw("bottom"),tC=tw("left"),tF={name:"text-align",initialValue:"left",prefix:!1,type:2,parse:function(A,e){switch(e){case"right":return 2;case"center":case"justify":return 1;default:return 0}}},th={name:"position",initialValue:"static",prefix:!1,type:2,parse:function(A,e){switch(e){case"relative":return 1;case"absolute":return 2;case"fixed":return 3;case"sticky":return 4}return 0}},td={name:"text-shadow",initialValue:"none",type:1,prefix:!1,parse:function(A,e){return 1===e.length&&AX(e[0],"none")?[]:AW(e).map(function(e){for(var t={color:eQ.TRANSPARENT,offsetX:Az,offsetY:Az,blur:Az},r=0,B=0;B<e.length;B++){var n=e[B];A_(n)?(0===r?t.offsetX=n:1===r?t.offsetY=n:t.blur=n,r++):t.color=A7.parse(A,n)}return t})}},tf={name:"text-transform",initialValue:"none",prefix:!1,type:2,parse:function(A,e){switch(e){case"uppercase":return 2;case"lowercase":return 1;case"capitalize":return 3}return 0}},tH={name:"transform",initialValue:"none",prefix:!0,type:0,parse:function(A,e){if(20===e.type&&"none"===e.value)return null;if(18===e.type){var t=tp[e.name];if(void 0===t)throw Error('Attempting to parse an unsupported transform function "'+e.name+'"');return t(e.values)}return null}},tp={matrix:function(A){var e=A.filter(function(A){return 17===A.type}).map(function(A){return A.number});return 6===e.length?e:null},matrix3d:function(A){var e=A.filter(function(A){return 17===A.type}).map(function(A){return A.number}),t=e[0],r=e[1];e[2],e[3];var B=e[4],n=e[5];e[6],e[7],e[8],e[9],e[10],e[11];var s=e[12],o=e[13];return e[14],e[15],16===e.length?[t,r,B,n,s,o]:null}},tE={type:16,number:50,flags:4},tI=[tE,tE],ty={name:"transform-origin",initialValue:"50% 50%",prefix:!0,type:1,parse:function(A,e){var t=e.filter(Aq);return 2!==t.length?tI:[t[0],t[1]]}},tK={name:"visible",initialValue:"none",prefix:!1,type:2,parse:function(A,e){switch(e){case"hidden":return 1;case"collapse":return 2;default:return 0}}};(Q=f||(f={})).NORMAL="normal",Q.BREAK_ALL="break-all",Q.KEEP_ALL="keep-all";for(var tm={name:"word-break",initialValue:"normal",prefix:!1,type:2,parse:function(A,e){switch(e){case"break-all":return f.BREAK_ALL;case"keep-all":return f.KEEP_ALL;default:return f.NORMAL}}},tL={name:"z-index",initialValue:"auto",prefix:!1,type:0,parse:function(A,e){if(20===e.type)return{auto:!0,order:0};if(AR(e))return{auto:!1,order:e.number};throw Error("Invalid z-index number parsed")}},tb={name:"time",parse:function(A,e){if(15===e.type)switch(e.unit.toLowerCase()){case"s":return 1e3*e.number;case"ms":return e.number}throw Error("Unsupported time type")}},tv={name:"opacity",initialValue:"1",type:0,prefix:!1,parse:function(A,e){return AR(e)?e.number:1}},tD={name:"text-decoration-color",initialValue:"transparent",prefix:!1,type:3,format:"color"},tx={name:"text-decoration-line",initialValue:"none",prefix:!1,type:1,parse:function(A,e){return e.filter(AN).map(function(A){switch(A.value){case"underline":return 1;case"overline":return 2;case"line-through":return 3;case"none":return 4}return 0}).filter(function(A){return 0!==A})}},tM={name:"font-family",initialValue:"",prefix:!1,type:1,parse:function(A,e){var t=[],r=[];return e.forEach(function(A){switch(A.type){case 20:case 0:t.push(A.value);break;case 17:t.push(A.number.toString());break;case 4:r.push(t.join(" ")),t.length=0}}),t.length&&r.push(t.join(" ")),r.map(function(A){return -1===A.indexOf(" ")?A:"'"+A+"'"})}},tS={name:"font-size",initialValue:"0",prefix:!1,type:3,format:"length"},tT={name:"font-weight",initialValue:"normal",type:0,prefix:!1,parse:function(A,e){return AR(e)?e.number:AN(e)&&"bold"===e.value?700:400}},tG={name:"font-variant",initialValue:"none",type:1,prefix:!1,parse:function(A,e){return e.filter(AN).map(function(A){return A.value})}},tO={name:"font-style",initialValue:"normal",prefix:!1,type:2,parse:function(A,e){switch(e){case"oblique":return"oblique";case"italic":return"italic";default:return"normal"}}},tV=function(A,e){return(A&e)!=0},tk={name:"content",initialValue:"none",type:1,prefix:!1,parse:function(A,e){if(0===e.length)return[];var t=e[0];return 20===t.type&&"none"===t.value?[]:e}},tR={name:"counter-increment",initialValue:"none",prefix:!0,type:1,parse:function(A,e){if(0===e.length)return null;var t=e[0];if(20===t.type&&"none"===t.value)return null;for(var r=[],B=e.filter(AJ),n=0;n<B.length;n++){var s=B[n],o=B[n+1];if(20===s.type){var i=o&&AR(o)?o.number:1;r.push({counter:s.value,increment:i})}}return r}},tN={name:"counter-reset",initialValue:"none",prefix:!0,type:1,parse:function(A,e){if(0===e.length)return[];for(var t=[],r=e.filter(AJ),B=0;B<r.length;B++){var n=r[B],s=r[B+1];if(AN(n)&&"none"!==n.value){var o=s&&AR(s)?s.number:0;t.push({counter:n.value,reset:o})}}return t}},tP={name:"duration",initialValue:"0s",prefix:!1,type:1,parse:function(A,e){return e.filter(Ak).map(function(e){return tb.parse(A,e)})}},tX={name:"quotes",initialValue:"none",prefix:!0,type:1,parse:function(A,e){if(0===e.length)return null;var t=e[0];if(20===t.type&&"none"===t.value)return null;var r=[],B=e.filter(AP);if(B.length%2!=0)return null;for(var n=0;n<B.length;n+=2){var s=B[n].value,o=B[n+1].value;r.push({open:s,close:o})}return r}},tJ=function(A,e,t){if(!A)return"";var r=A[Math.min(e,A.length-1)];return r?t?r.open:r.close:""},tY={name:"box-shadow",initialValue:"none",type:1,prefix:!1,parse:function(A,e){return 1===e.length&&AX(e[0],"none")?[]:AW(e).map(function(e){for(var t={color:255,offsetX:Az,offsetY:Az,blur:Az,spread:Az,inset:!1},r=0,B=0;B<e.length;B++){var n=e[B];AX(n,"inset")?t.inset=!0:A_(n)?(0===r?t.offsetX=n:1===r?t.offsetY=n:2===r?t.blur=n:t.spread=n,r++):t.color=A7.parse(A,n)}return t})}},tW={name:"paint-order",initialValue:"normal",prefix:!1,type:1,parse:function(A,e){var t=[];return e.filter(AN).forEach(function(A){switch(A.value){case"stroke":t.push(1);break;case"fill":t.push(0);break;case"markers":t.push(2)}}),[0,1,2].forEach(function(A){-1===t.indexOf(A)&&t.push(A)}),t}},tZ={name:"-webkit-text-stroke-color",initialValue:"currentcolor",prefix:!1,type:3,format:"color"},t_={name:"-webkit-text-stroke-width",initialValue:"0",type:0,prefix:!1,parse:function(A,e){return Ak(e)?e.number:0}},tq=function(){function A(A,e){this.animationDuration=t$(A,tP,e.animationDuration),this.backgroundClip=t$(A,ea,e.backgroundClip),this.backgroundColor=t$(A,ec,e.backgroundColor),this.backgroundImage=t$(A,ev,e.backgroundImage),this.backgroundOrigin=t$(A,eD,e.backgroundOrigin),this.backgroundPosition=t$(A,ex,e.backgroundPosition),this.backgroundRepeat=t$(A,eM,e.backgroundRepeat),this.backgroundSize=t$(A,eT,e.backgroundSize),this.borderTopColor=t$(A,eV,e.borderTopColor),this.borderRightColor=t$(A,ek,e.borderRightColor),this.borderBottomColor=t$(A,eR,e.borderBottomColor),this.borderLeftColor=t$(A,eN,e.borderLeftColor),this.borderTopLeftRadius=t$(A,eX,e.borderTopLeftRadius),this.borderTopRightRadius=t$(A,eJ,e.borderTopRightRadius),this.borderBottomRightRadius=t$(A,eY,e.borderBottomRightRadius),this.borderBottomLeftRadius=t$(A,eW,e.borderBottomLeftRadius),this.borderTopStyle=t$(A,e_,e.borderTopStyle),this.borderRightStyle=t$(A,eq,e.borderRightStyle),this.borderBottomStyle=t$(A,ej,e.borderBottomStyle),this.borderLeftStyle=t$(A,ez,e.borderLeftStyle),this.borderTopWidth=t$(A,e0,e.borderTopWidth),this.borderRightWidth=t$(A,e4,e.borderRightWidth),this.borderBottomWidth=t$(A,e1,e.borderBottomWidth),this.borderLeftWidth=t$(A,e2,e.borderLeftWidth),this.boxShadow=t$(A,tY,e.boxShadow),this.color=t$(A,e3,e.color),this.direction=t$(A,e5,e.direction),this.display=t$(A,e6,e.display),this.float=t$(A,e9,e.cssFloat),this.fontFamily=t$(A,tM,e.fontFamily),this.fontSize=t$(A,tS,e.fontSize),this.fontStyle=t$(A,tO,e.fontStyle),this.fontVariant=t$(A,tG,e.fontVariant),this.fontWeight=t$(A,tT,e.fontWeight),this.letterSpacing=t$(A,e7,e.letterSpacing),this.lineBreak=t$(A,tA,e.lineBreak),this.lineHeight=t$(A,te,e.lineHeight),this.listStyleImage=t$(A,tr,e.listStyleImage),this.listStylePosition=t$(A,tB,e.listStylePosition),this.listStyleType=t$(A,tn,e.listStyleType),this.marginTop=t$(A,to,e.marginTop),this.marginRight=t$(A,ti,e.marginRight),this.marginBottom=t$(A,tQ,e.marginBottom),this.marginLeft=t$(A,ta,e.marginLeft),this.opacity=t$(A,tv,e.opacity);var t,r,B=t$(A,tc,e.overflow);this.overflowX=B[0],this.overflowY=B[B.length>1?1:0],this.overflowWrap=t$(A,tg,e.overflowWrap),this.paddingTop=t$(A,tl,e.paddingTop),this.paddingRight=t$(A,tU,e.paddingRight),this.paddingBottom=t$(A,tu,e.paddingBottom),this.paddingLeft=t$(A,tC,e.paddingLeft),this.paintOrder=t$(A,tW,e.paintOrder),this.position=t$(A,th,e.position),this.textAlign=t$(A,tF,e.textAlign),this.textDecorationColor=t$(A,tD,null!==(t=e.textDecorationColor)&&void 0!==t?t:e.color),this.textDecorationLine=t$(A,tx,null!==(r=e.textDecorationLine)&&void 0!==r?r:e.textDecoration),this.textShadow=t$(A,td,e.textShadow),this.textTransform=t$(A,tf,e.textTransform),this.transform=t$(A,tH,e.transform),this.transformOrigin=t$(A,ty,e.transformOrigin),this.visibility=t$(A,tK,e.visibility),this.webkitTextStrokeColor=t$(A,tZ,e.webkitTextStrokeColor),this.webkitTextStrokeWidth=t$(A,t_,e.webkitTextStrokeWidth),this.wordBreak=t$(A,tm,e.wordBreak),this.zIndex=t$(A,tL,e.zIndex)}return A.prototype.isVisible=function(){return this.display>0&&this.opacity>0&&0===this.visibility},A.prototype.isTransparent=function(){return eA(this.backgroundColor)},A.prototype.isTransformed=function(){return null!==this.transform},A.prototype.isPositioned=function(){return 0!==this.position},A.prototype.isPositionedWithZIndex=function(){return this.isPositioned()&&!this.zIndex.auto},A.prototype.isFloating=function(){return 0!==this.float},A.prototype.isInlineLevel=function(){return tV(this.display,4)||tV(this.display,33554432)||tV(this.display,268435456)||tV(this.display,536870912)||tV(this.display,67108864)||tV(this.display,134217728)},A}(),tj=function(A,e){this.content=t$(A,tk,e.content),this.quotes=t$(A,tX,e.quotes)},tz=function(A,e){this.counterIncrement=t$(A,tR,e.counterIncrement),this.counterReset=t$(A,tN,e.counterReset)},t$=function(A,e,t){var r=new AO,B=null!=t?t.toString():e.initialValue;r.write(B);var n=new AV(r.read());switch(e.type){case 2:var s=n.parseComponentValue();return e.parse(A,AN(s)?s.value:e.initialValue);case 0:return e.parse(A,n.parseComponentValue());case 1:return e.parse(A,n.parseComponentValues());case 4:return n.parseComponentValue();case 3:switch(e.format){case"angle":return A5.parse(A,n.parseComponentValue());case"color":return A7.parse(A,n.parseComponentValue());case"image":return eL.parse(A,n.parseComponentValue());case"length":var o=n.parseComponentValue();return A_(o)?o:Az;case"length-percentage":var i=n.parseComponentValue();return Aq(i)?i:Az;case"time":return tb.parse(A,n.parseComponentValue())}}},t0=function(A){switch(A.getAttribute("data-html2canvas-debug")){case"all":return 1;case"clone":return 2;case"parse":return 3;case"render":return 4;default:return 0}},t4=function(A,e){var t=t0(A);return 1===t||e===t},t1=function(A,e){this.context=A,this.textNodes=[],this.elements=[],this.flags=0,t4(e,3),this.styles=new tq(A,window.getComputedStyle(e,null)),r5(e)&&(this.styles.animationDuration.some(function(A){return A>0})&&(e.style.animationDuration="0s"),null!==this.styles.transform&&(e.style.transform="none")),this.bounds=v(this.context,e),t4(e,4)&&(this.flags|=16)},t2="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",t3="undefined"==typeof Uint8Array?[]:new Uint8Array(256),t5=0;t5<t2.length;t5++)t3[t2.charCodeAt(t5)]=t5;for(var t6=function(A,e,t){return A.slice?A.slice(e,t):new Uint16Array(Array.prototype.slice.call(A,e,t))},t8=function(){function A(A,e,t,r,B,n){this.initialValue=A,this.errorValue=e,this.highStart=t,this.highValueIndex=r,this.index=B,this.data=n}return A.prototype.get=function(A){var e;if(A>=0){if(A<55296||A>56319&&A<=65535)return e=((e=this.index[A>>5])<<2)+(31&A),this.data[e];if(A<=65535)return e=((e=this.index[2048+(A-55296>>5)])<<2)+(31&A),this.data[e];if(A<this.highStart)return e=2080+(A>>11),e=this.index[e]+(A>>5&63),e=((e=this.index[e])<<2)+(31&A),this.data[e];if(A<=1114111)return this.data[this.highValueIndex]}return this.errorValue},A}(),t9="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",t7="undefined"==typeof Uint8Array?[]:new Uint8Array(256),rA=0;rA<t9.length;rA++)t7[t9.charCodeAt(rA)]=rA;var re=function(A){for(var e=[],t=0,r=A.length;t<r;){var B=A.charCodeAt(t++);if(B>=55296&&B<=56319&&t<r){var n=A.charCodeAt(t++);(64512&n)==56320?e.push(((1023&B)<<10)+(1023&n)+65536):(e.push(B),t--)}else e.push(B)}return e},rt=function(){for(var A=[],e=0;e<arguments.length;e++)A[e]=arguments[e];if(String.fromCodePoint)return String.fromCodePoint.apply(String,A);var t=A.length;if(!t)return"";for(var r=[],B=-1,n="";++B<t;){var s=A[B];s<=65535?r.push(s):(s-=65536,r.push((s>>10)+55296,s%1024+56320)),(B+1===t||r.length>16384)&&(n+=String.fromCharCode.apply(String,r),r.length=0)}return n},rr=(c=Array.isArray(a=function(A){var e,t,r,B,n,s=.75*A.length,o=A.length,i=0;"="===A[A.length-1]&&(s--,"="===A[A.length-2]&&s--);var Q="undefined"!=typeof ArrayBuffer&&"undefined"!=typeof Uint8Array&&void 0!==Uint8Array.prototype.slice?new ArrayBuffer(s):Array(s),a=Array.isArray(Q)?Q:new Uint8Array(Q);for(e=0;e<o;e+=4)t=t3[A.charCodeAt(e)],r=t3[A.charCodeAt(e+1)],B=t3[A.charCodeAt(e+2)],n=t3[A.charCodeAt(e+3)],a[i++]=t<<2|r>>4,a[i++]=(15&r)<<4|B>>2,a[i++]=(3&B)<<6|63&n;return Q}(" "))?function(A){for(var e=A.length,t=[],r=0;r<e;r+=4)t.push(A[r+3]<<24|A[r+2]<<16|A[r+1]<<8|A[r]);return t}(a):new Uint32Array(a),w=t6(g=Array.isArray(a)?function(A){for(var e=A.length,t=[],r=0;r<e;r+=2)t.push(A[r+1]<<8|A[r]);return t}(a):new Uint16Array(a),12,c[4]/2),u=2===c[5]?t6(g,(24+c[4])/2):(l=Math.ceil((24+c[4])/4),c.slice?c.slice(l,U):new Uint32Array(Array.prototype.slice.call(c,l,U))),new t8(c[0],c[1],c[2],c[3],w,u)),rB=function(A){return rr.get(A)},rn=function(A,e,t){var r=t-2,B=e[r],n=e[t-1],s=e[t];if(2===n&&3===s)return"\xd7";if(2===n||3===n||4===n||2===s||3===s||4===s)return"\xf7";if(8===n&&-1!==[8,9,11,12].indexOf(s)||(11===n||9===n)&&(9===s||10===s)||(12===n||10===n)&&10===s||13===s||5===s||7===s||1===n)return"\xd7";if(13===n&&14===s){for(;5===B;)B=e[--r];if(14===B)return"\xd7"}if(15===n&&15===s){for(var o=0;15===B;)o++,B=e[--r];if(o%2==0)return"\xd7"}return"\xf7"},rs=function(A){var e=re(A),t=e.length,r=0,B=0,n=e.map(rB);return{next:function(){if(r>=t)return{done:!0,value:null};for(var A="\xd7";r<t&&"\xd7"===(A=rn(e,n,++r)););if("\xd7"!==A||r===t){var s=rt.apply(null,e.slice(B,r));return B=r,{value:s,done:!1}}return{done:!0,value:null}}}},ro=function(A){for(var e,t=rs(A),r=[];!(e=t.next()).done;)e.value&&r.push(e.value.slice());return r},ri=function(A){if(A.createRange){var e=A.createRange();if(e.getBoundingClientRect){var t=A.createElement("boundtest");t.style.height="123px",t.style.display="block",A.body.appendChild(t),e.selectNode(t);var r=Math.round(e.getBoundingClientRect().height);if(A.body.removeChild(t),123===r)return!0}}return!1},rQ=function(A){var e=A.createElement("boundtest");e.style.width="50px",e.style.display="block",e.style.fontSize="12px",e.style.letterSpacing="0px",e.style.wordSpacing="0px",A.body.appendChild(e);var t=A.createRange();e.innerHTML="function"==typeof"".repeat?"&#128104;".repeat(10):"";var r=e.firstChild,B=x(r.data).map(function(A){return M(A)}),n=0,s={},o=B.every(function(A,e){t.setStart(r,n),t.setEnd(r,n+A.length);var B=t.getBoundingClientRect();n+=A.length;var o=B.x>s.x||B.y>s.y;return s=B,0===e||o});return A.body.removeChild(e),o},ra=function(A){var e=new Image,t=A.createElement("canvas"),r=t.getContext("2d");if(!r)return!1;e.src="data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg'></svg>";try{r.drawImage(e,0,0),t.toDataURL()}catch(A){return!1}return!0},rc=function(A){return 0===A[0]&&255===A[1]&&0===A[2]&&255===A[3]},rg=function(A){var e=A.createElement("canvas");e.width=100,e.height=100;var t=e.getContext("2d");if(!t)return Promise.reject(!1);t.fillStyle="rgb(0, 255, 0)",t.fillRect(0,0,100,100);var r=new Image,B=e.toDataURL();r.src=B;var n=rw(100,100,0,0,r);return t.fillStyle="red",t.fillRect(0,0,100,100),rl(n).then(function(e){t.drawImage(e,0,0);var r=t.getImageData(0,0,100,100).data;t.fillStyle="red",t.fillRect(0,0,100,100);var n=A.createElement("div");return n.style.backgroundImage="url("+B+")",n.style.height="100px",rc(r)?rl(rw(100,100,0,0,n)):Promise.reject(!1)}).then(function(A){return t.drawImage(A,0,0),rc(t.getImageData(0,0,100,100).data)}).catch(function(){return!1})},rw=function(A,e,t,r,B){var n="http://www.w3.org/2000/svg",s=document.createElementNS(n,"svg"),o=document.createElementNS(n,"foreignObject");return s.setAttributeNS(null,"width",A.toString()),s.setAttributeNS(null,"height",e.toString()),o.setAttributeNS(null,"width","100%"),o.setAttributeNS(null,"height","100%"),o.setAttributeNS(null,"x",t.toString()),o.setAttributeNS(null,"y",r.toString()),o.setAttributeNS(null,"externalResourcesRequired","true"),s.appendChild(o),o.appendChild(B),s},rl=function(A){return new Promise(function(e,t){var r=new Image;r.onload=function(){return e(r)},r.onerror=t,r.src="data:image/svg+xml;charset=utf-8,"+encodeURIComponent(new XMLSerializer().serializeToString(A))})},rU={get SUPPORT_RANGE_BOUNDS(){var ru=ri(document);return Object.defineProperty(rU,"SUPPORT_RANGE_BOUNDS",{value:ru}),ru},get SUPPORT_WORD_BREAKING(){var rC=rU.SUPPORT_RANGE_BOUNDS&&rQ(document);return Object.defineProperty(rU,"SUPPORT_WORD_BREAKING",{value:rC}),rC},get SUPPORT_SVG_DRAWING(){var rF=ra(document);return Object.defineProperty(rU,"SUPPORT_SVG_DRAWING",{value:rF}),rF},get SUPPORT_FOREIGNOBJECT_DRAWING(){var rh="function"==typeof Array.from&&"function"==typeof window.fetch?rg(document):Promise.resolve(!1);return Object.defineProperty(rU,"SUPPORT_FOREIGNOBJECT_DRAWING",{value:rh}),rh},get SUPPORT_CORS_IMAGES(){var rd=void 0!==new Image().crossOrigin;return Object.defineProperty(rU,"SUPPORT_CORS_IMAGES",{value:rd}),rd},get SUPPORT_RESPONSE_TYPE(){var rf="string"==typeof new XMLHttpRequest().responseType;return Object.defineProperty(rU,"SUPPORT_RESPONSE_TYPE",{value:rf}),rf},get SUPPORT_CORS_XHR(){var rH="withCredentials"in new XMLHttpRequest;return Object.defineProperty(rU,"SUPPORT_CORS_XHR",{value:rH}),rH},get SUPPORT_NATIVE_TEXT_SEGMENTATION(){var rp=!!("undefined"!=typeof Intl&&Intl.Segmenter);return Object.defineProperty(rU,"SUPPORT_NATIVE_TEXT_SEGMENTATION",{value:rp}),rp}},rE=function(A,e){this.text=A,this.bounds=e},rI=function(A,e,t,r){var B=rL(e,t),n=[],s=0;return B.forEach(function(e){if(t.textDecorationLine.length||e.trim().length>0){if(rU.SUPPORT_RANGE_BOUNDS){var B=rK(r,s,e.length).getClientRects();if(B.length>1){var o=rm(e),i=0;o.forEach(function(e){n.push(new rE(e,b.fromDOMRectList(A,rK(r,i+s,e.length).getClientRects()))),i+=e.length})}else n.push(new rE(e,b.fromDOMRectList(A,B)))}else{var Q=r.splitText(e.length);n.push(new rE(e,ry(A,r))),r=Q}}else rU.SUPPORT_RANGE_BOUNDS||(r=r.splitText(e.length));s+=e.length}),n},ry=function(A,e){var t=e.ownerDocument;if(t){var r=t.createElement("html2canvaswrapper");r.appendChild(e.cloneNode(!0));var B=e.parentNode;if(B){B.replaceChild(r,e);var n=v(A,r);return r.firstChild&&B.replaceChild(r.firstChild,r),n}}return b.EMPTY},rK=function(A,e,t){var r=A.ownerDocument;if(!r)throw Error("Node has no owner document");var B=r.createRange();return B.setStart(A,e),B.setEnd(A,e+t),B},rm=function(A){return rU.SUPPORT_NATIVE_TEXT_SEGMENTATION?Array.from(new Intl.Segmenter(void 0,{granularity:"grapheme"}).segment(A)).map(function(A){return A.segment}):ro(A)},rL=function(A,e){return 0!==e.letterSpacing?rm(A):rU.SUPPORT_NATIVE_TEXT_SEGMENTATION?Array.from(new Intl.Segmenter(void 0,{granularity:"word"}).segment(A)).map(function(A){return A.segment}):rv(A,e)},rb=[32,160,4961,65792,65793,4153,4241],rv=function(A,e){for(var t,r=Ao(A,{lineBreak:e.lineBreak,wordBreak:"break-word"===e.overflowWrap?"break-word":e.wordBreak}),B=[];!(t=r.next()).done;)!function(){if(t.value){var A=x(t.value.slice()),e="";A.forEach(function(A){-1===rb.indexOf(A)?e+=M(A):(e.length&&B.push(e),B.push(M(A)),e="")}),e.length&&B.push(e)}}();return B},rD=function(A,e,t){this.text=rx(e.data,t.textTransform),this.textBounds=rI(A,this.text,t,e)},rx=function(A,e){switch(e){case 1:return A.toLowerCase();case 3:return A.replace(rM,rS);case 2:return A.toUpperCase();default:return A}},rM=/(^|\s|:|-|\(|\))([a-z])/g,rS=function(A,e,t){return A.length>0?e+t.toUpperCase():A},rT=function(A){function e(e,t){var r=A.call(this,e,t)||this;return r.src=t.currentSrc||t.src,r.intrinsicWidth=t.naturalWidth,r.intrinsicHeight=t.naturalHeight,r.context.cache.addImage(r.src),r}return I(e,A),e}(t1),rG=function(A){function e(e,t){var r=A.call(this,e,t)||this;return r.canvas=t,r.intrinsicWidth=t.width,r.intrinsicHeight=t.height,r}return I(e,A),e}(t1),rO=function(A){function e(e,t){var r=A.call(this,e,t)||this,B=new XMLSerializer,n=v(e,t);return t.setAttribute("width",n.width+"px"),t.setAttribute("height",n.height+"px"),r.svg="data:image/svg+xml,"+encodeURIComponent(B.serializeToString(t)),r.intrinsicWidth=t.width.baseVal.value,r.intrinsicHeight=t.height.baseVal.value,r.context.cache.addImage(r.svg),r}return I(e,A),e}(t1),rV=function(A){function e(e,t){var r=A.call(this,e,t)||this;return r.value=t.value,r}return I(e,A),e}(t1),rk=function(A){function e(e,t){var r=A.call(this,e,t)||this;return r.start=t.start,r.reversed="boolean"==typeof t.reversed&&!0===t.reversed,r}return I(e,A),e}(t1),rR=[{type:15,flags:0,unit:"px",number:3}],rN=[{type:16,flags:0,number:50}],rP=function(A){var e=A.type===rY?Array(A.value.length+1).join("•"):A.value;return 0===e.length?A.placeholder||"":e},rX="checkbox",rJ="radio",rY="password",rW=function(A){function e(e,t){var r,B=A.call(this,e,t)||this;switch(B.type=t.type.toLowerCase(),B.checked=t.checked,B.value=rP(t),(B.type===rX||B.type===rJ)&&(B.styles.backgroundColor=3739148031,B.styles.borderTopColor=B.styles.borderRightColor=B.styles.borderBottomColor=B.styles.borderLeftColor=2779096575,B.styles.borderTopWidth=B.styles.borderRightWidth=B.styles.borderBottomWidth=B.styles.borderLeftWidth=1,B.styles.borderTopStyle=B.styles.borderRightStyle=B.styles.borderBottomStyle=B.styles.borderLeftStyle=1,B.styles.backgroundClip=[0],B.styles.backgroundOrigin=[0],B.bounds=(r=B.bounds).width>r.height?new b(r.left+(r.width-r.height)/2,r.top,r.height,r.height):r.width<r.height?new b(r.left,r.top+(r.height-r.width)/2,r.width,r.width):r),B.type){case rX:B.styles.borderTopRightRadius=B.styles.borderTopLeftRadius=B.styles.borderBottomRightRadius=B.styles.borderBottomLeftRadius=rR;break;case rJ:B.styles.borderTopRightRadius=B.styles.borderTopLeftRadius=B.styles.borderBottomRightRadius=B.styles.borderBottomLeftRadius=rN}return B}return I(e,A),e}(t1),rZ=function(A){function e(e,t){var r=A.call(this,e,t)||this,B=t.options[t.selectedIndex||0];return r.value=B&&B.text||"",r}return I(e,A),e}(t1),r_=function(A){function e(e,t){var r=A.call(this,e,t)||this;return r.value=t.value,r}return I(e,A),e}(t1),rq=function(A){function e(e,t){var r=A.call(this,e,t)||this;r.src=t.src,r.width=parseInt(t.width,10)||0,r.height=parseInt(t.height,10)||0,r.backgroundColor=r.styles.backgroundColor;try{if(t.contentWindow&&t.contentWindow.document&&t.contentWindow.document.documentElement){r.tree=r0(e,t.contentWindow.document.documentElement);var B=t.contentWindow.document.documentElement?ei(e,getComputedStyle(t.contentWindow.document.documentElement).backgroundColor):eQ.TRANSPARENT,n=t.contentWindow.document.body?ei(e,getComputedStyle(t.contentWindow.document.body).backgroundColor):eQ.TRANSPARENT;r.backgroundColor=eA(B)?eA(n)?r.styles.backgroundColor:n:B}}catch(A){}return r}return I(e,A),e}(t1),rj=["OL","UL","MENU"],rz=function(A,e,t,r){for(var B=e.firstChild,n=void 0;B;B=n)if(n=B.nextSibling,r2(B)&&B.data.trim().length>0)t.textNodes.push(new rD(A,B,t.styles));else if(r3(B)){if(BQ(B)&&B.assignedNodes)B.assignedNodes().forEach(function(e){return rz(A,e,t,r)});else{var s=r$(A,B);!s.styles.isVisible()||(r4(B,s,r)?s.flags|=4:r1(s.styles)&&(s.flags|=2),-1!==rj.indexOf(B.tagName)&&(s.flags|=8),t.elements.push(s),B.slot,B.shadowRoot?rz(A,B.shadowRoot,s,r):Bo(B)||BA(B)||Bi(B)||rz(A,B,s,r))}}},r$=function(A,e){return BB(e)?new rT(A,e):Bt(e)?new rG(A,e):BA(e)?new rO(A,e):r8(e)?new rV(A,e):r9(e)?new rk(A,e):r7(e)?new rW(A,e):Bi(e)?new rZ(A,e):Bo(e)?new r_(A,e):Bn(e)?new rq(A,e):new t1(A,e)},r0=function(A,e){var t=r$(A,e);return t.flags|=4,rz(A,e,t,t),t},r4=function(A,e,t){return e.styles.isPositionedWithZIndex()||e.styles.opacity<1||e.styles.isTransformed()||Be(A)&&t.styles.isTransparent()},r1=function(A){return A.isPositioned()||A.isFloating()},r2=function(A){return A.nodeType===Node.TEXT_NODE},r3=function(A){return A.nodeType===Node.ELEMENT_NODE},r5=function(A){return r3(A)&&void 0!==A.style&&!r6(A)},r6=function(A){return"object"==typeof A.className},r8=function(A){return"LI"===A.tagName},r9=function(A){return"OL"===A.tagName},r7=function(A){return"INPUT"===A.tagName},BA=function(A){return"svg"===A.tagName},Be=function(A){return"BODY"===A.tagName},Bt=function(A){return"CANVAS"===A.tagName},Br=function(A){return"VIDEO"===A.tagName},BB=function(A){return"IMG"===A.tagName},Bn=function(A){return"IFRAME"===A.tagName},Bs=function(A){return"STYLE"===A.tagName},Bo=function(A){return"TEXTAREA"===A.tagName},Bi=function(A){return"SELECT"===A.tagName},BQ=function(A){return"SLOT"===A.tagName},Ba=function(A){return A.tagName.indexOf("-")>0},Bc=function(){function A(){this.counters={}}return A.prototype.getCounterValue=function(A){var e=this.counters[A];return e&&e.length?e[e.length-1]:1},A.prototype.getCounterValues=function(A){return this.counters[A]||[]},A.prototype.pop=function(A){var e=this;A.forEach(function(A){return e.counters[A].pop()})},A.prototype.parse=function(A){var e=this,t=A.counterIncrement,r=A.counterReset,B=!0;null!==t&&t.forEach(function(A){var t=e.counters[A.counter];t&&0!==A.increment&&(B=!1,t.length||t.push(1),t[Math.max(0,t.length-1)]+=A.increment)});var n=[];return B&&r.forEach(function(A){var t=e.counters[A.counter];n.push(A.counter),t||(t=e.counters[A.counter]=[]),t.push(A.reset)}),n},A}(),Bg={integers:[1e3,900,500,400,100,90,50,40,10,9,5,4,1],values:["M","CM","D","CD","C","XC","L","XL","X","IX","V","IV","I"]},Bw={integers:[9e3,8e3,7e3,6e3,5e3,4e3,3e3,2e3,1e3,900,800,700,600,500,400,300,200,100,90,80,70,60,50,40,30,20,10,9,8,7,6,5,4,3,2,1],values:["Ք","Փ","Ւ","Ց","Ր","Տ","Վ","Ս","Ռ","Ջ","Պ","Չ","Ո","Շ","Ն","Յ","Մ","Ճ","Ղ","Ձ","Հ","Կ","Ծ","Խ","Լ","Ի","Ժ","Թ","Ը","Է","Զ","Ե","Դ","Գ","Բ","Ա"]},Bl={integers:[1e4,9e3,8e3,7e3,6e3,5e3,4e3,3e3,2e3,1e3,400,300,200,100,90,80,70,60,50,40,30,20,19,18,17,16,15,10,9,8,7,6,5,4,3,2,1],values:["י׳","ט׳","ח׳","ז׳","ו׳","ה׳","ד׳","ג׳","ב׳","א׳","ת","ש","ר","ק","צ","פ","ע","ס","נ","מ","ל","כ","יט","יח","יז","טז","טו","י","ט","ח","ז","ו","ה","ד","ג","ב","א"]},BU={integers:[1e4,9e3,8e3,7e3,6e3,5e3,4e3,3e3,2e3,1e3,900,800,700,600,500,400,300,200,100,90,80,70,60,50,40,30,20,10,9,8,7,6,5,4,3,2,1],values:["ჵ","ჰ","ჯ","ჴ","ხ","ჭ","წ","ძ","ც","ჩ","შ","ყ","ღ","ქ","ფ","ჳ","ტ","ს","რ","ჟ","პ","ო","ჲ","ნ","მ","ლ","კ","ი","თ","ჱ","ზ","ვ","ე","დ","გ","ბ","ა"]},Bu=function(A,e,t,r,B,n){return A<e||A>t?BI(A,B,n.length>0):r.integers.reduce(function(e,t,B){for(;A>=t;)A-=t,e+=r.values[B];return e},"")+n},BC=function(A,e,t,r){var B="";do!t&&A--,B=r(A)+B,A/=e;while(A*e>=e);return B},BF=function(A,e,t,r,B){var n=t-e+1;return(A<0?"-":"")+(BC(Math.abs(A),n,r,function(A){return M(Math.floor(A%n)+e)})+B)},Bh=function(A,e,t){void 0===t&&(t=". ");var r=e.length;return BC(Math.abs(A),r,!1,function(A){return e[Math.floor(A%r)]})+t},Bd=function(A,e,t,r,B,n){if(A<-9999||A>9999)return BI(A,4,B.length>0);var s=Math.abs(A),o=B;if(0===s)return e[0]+o;for(var i=0;s>0&&i<=4;i++){var Q=s%10;0===Q&&tV(n,1)&&""!==o?o=e[Q]+o:Q>1||1===Q&&0===i||1===Q&&1===i&&tV(n,2)||1===Q&&1===i&&tV(n,4)&&A>100||1===Q&&i>1&&tV(n,8)?o=e[Q]+(i>0?t[i-1]:"")+o:1===Q&&i>0&&(o=t[i-1]+o),s=Math.floor(s/10)}return(A<0?r:"")+o},Bf="十百千萬",BH="拾佰仟萬",Bp="マイナス",BE="마이너스",BI=function(A,e,t){var r=t?". ":"",B=t?"、":"",n=t?", ":"",s=t?" ":"";switch(e){case 0:return"•"+s;case 1:return"◦"+s;case 2:return"◾"+s;case 5:var o=BF(A,48,57,!0,r);return o.length<4?"0"+o:o;case 4:return Bh(A,"〇一二三四五六七八九",B);case 6:return Bu(A,1,3999,Bg,3,r).toLowerCase();case 7:return Bu(A,1,3999,Bg,3,r);case 8:return BF(A,945,969,!1,r);case 9:return BF(A,97,122,!1,r);case 10:return BF(A,65,90,!1,r);case 11:return BF(A,1632,1641,!0,r);case 12:case 49:return Bu(A,1,9999,Bw,3,r);case 35:return Bu(A,1,9999,Bw,3,r).toLowerCase();case 13:return BF(A,2534,2543,!0,r);case 14:case 30:return BF(A,6112,6121,!0,r);case 15:return Bh(A,"子丑寅卯辰巳午未申酉戌亥",B);case 16:return Bh(A,"甲乙丙丁戊己庚辛壬癸",B);case 17:case 48:return Bd(A,"零一二三四五六七八九",Bf,"負",B,14);case 47:return Bd(A,"零壹貳參肆伍陸柒捌玖",BH,"負",B,15);case 42:return Bd(A,"零一二三四五六七八九",Bf,"负",B,14);case 41:return Bd(A,"零壹贰叁肆伍陆柒捌玖",BH,"负",B,15);case 26:return Bd(A,"〇一二三四五六七八九","十百千万",Bp,B,0);case 25:return Bd(A,"零壱弐参四伍六七八九","拾百千万",Bp,B,7);case 31:return Bd(A,"영일이삼사오육칠팔구","십백천만",BE,n,7);case 33:return Bd(A,"零一二三四五六七八九","十百千萬",BE,n,0);case 32:return Bd(A,"零壹貳參四五六七八九","拾百千",BE,n,7);case 18:return BF(A,2406,2415,!0,r);case 20:return Bu(A,1,19999,BU,3,r);case 21:return BF(A,2790,2799,!0,r);case 22:return BF(A,2662,2671,!0,r);case 22:return Bu(A,1,10999,Bl,3,r);case 23:return Bh(A,"あいうえおかきくけこさしすせそたちつてとなにぬねのはひふへほまみむめもやゆよらりるれろわゐゑをん");case 24:return Bh(A,"いろはにほへとちりぬるをわかよたれそつねならむうゐのおくやまけふこえてあさきゆめみしゑひもせす");case 27:return BF(A,3302,3311,!0,r);case 28:return Bh(A,"アイウエオカキクケコサシスセソタチツテトナニヌネノハヒフヘホマミムメモヤユヨラリルレロワヰヱヲン",B);case 29:return Bh(A,"イロハニホヘトチリヌルヲワカヨタレソツネナラムウヰノオクヤマケフコエテアサキユメミシヱヒモセス",B);case 34:return BF(A,3792,3801,!0,r);case 37:return BF(A,6160,6169,!0,r);case 38:return BF(A,4160,4169,!0,r);case 39:return BF(A,2918,2927,!0,r);case 40:return BF(A,1776,1785,!0,r);case 43:return BF(A,3046,3055,!0,r);case 44:return BF(A,3174,3183,!0,r);case 45:return BF(A,3664,3673,!0,r);case 46:return BF(A,3872,3881,!0,r);default:return BF(A,48,57,!0,r)}},By="data-html2canvas-ignore",BK=function(){function A(A,e,t){if(this.context=A,this.options=t,this.scrolledElements=[],this.referenceElement=e,this.counters=new Bc,this.quoteDepth=0,!e.ownerDocument)throw Error("Cloned element does not have an owner document");this.documentElement=this.cloneNode(e.ownerDocument.documentElement,!1)}return A.prototype.toIFrame=function(A,e){var t=this,r=Bm(A,e);if(!r.contentWindow)return Promise.reject("Unable to find iframe window");var B=A.defaultView.pageXOffset,n=A.defaultView.pageYOffset,s=r.contentWindow,o=s.document,i=Bv(r).then(function(){return K(t,void 0,void 0,function(){var A,t;return m(this,function(B){switch(B.label){case 0:if(this.scrolledElements.forEach(BT),s&&(s.scrollTo(e.left,e.top),/(iPad|iPhone|iPod)/g.test(navigator.userAgent)&&(s.scrollY!==e.top||s.scrollX!==e.left)&&(this.context.logger.warn("Unable to restore scroll position for cloned document"),this.context.windowBounds=this.context.windowBounds.add(s.scrollX-e.left,s.scrollY-e.top,0,0))),A=this.options.onclone,void 0===(t=this.clonedReferenceElement))return[2,Promise.reject("Error finding the "+this.referenceElement.nodeName+" in the cloned document")];if(!(o.fonts&&o.fonts.ready))return[3,2];return[4,o.fonts.ready];case 1:B.sent(),B.label=2;case 2:if(!/(AppleWebKit)/g.test(navigator.userAgent))return[3,4];return[4,Bb(o)];case 3:B.sent(),B.label=4;case 4:if("function"==typeof A)return[2,Promise.resolve().then(function(){return A(o,t)}).then(function(){return r})];return[2,r]}})})});return o.open(),o.write(BM(document.doctype)+"<html></html>"),BS(this.referenceElement.ownerDocument,B,n),o.replaceChild(o.adoptNode(this.documentElement),o.documentElement),o.close(),i},A.prototype.createElementClone=function(A){if(t4(A,2),Bt(A))return this.createCanvasClone(A);if(Br(A))return this.createVideoClone(A);if(Bs(A))return this.createStyleClone(A);var e=A.cloneNode(!1);return(BB(e)&&(BB(A)&&A.currentSrc&&A.currentSrc!==A.src&&(e.src=A.currentSrc,e.srcset=""),"lazy"===e.loading&&(e.loading="eager")),Ba(e))?this.createCustomElementClone(e):e},A.prototype.createCustomElementClone=function(A){var e=document.createElement("html2canvascustomelement");return Bx(A.style,e),e},A.prototype.createStyleClone=function(A){try{var e=A.sheet;if(e&&e.cssRules){var t=[].slice.call(e.cssRules,0).reduce(function(A,e){return e&&"string"==typeof e.cssText?A+e.cssText:A},""),r=A.cloneNode(!1);return r.textContent=t,r}}catch(A){if(this.context.logger.error("Unable to access cssRules property",A),"SecurityError"!==A.name)throw A}return A.cloneNode(!1)},A.prototype.createCanvasClone=function(A){if(this.options.inlineImages&&A.ownerDocument){var e,t=A.ownerDocument.createElement("img");try{return t.src=A.toDataURL(),t}catch(e){this.context.logger.info("Unable to inline canvas contents, canvas is tainted",A)}}var r=A.cloneNode(!1);try{r.width=A.width,r.height=A.height;var B=A.getContext("2d"),n=r.getContext("2d");if(n){if(!this.options.allowTaint&&B)n.putImageData(B.getImageData(0,0,A.width,A.height),0,0);else{var s=null!==(e=A.getContext("webgl2"))&&void 0!==e?e:A.getContext("webgl");if(s){var o=s.getContextAttributes();(null==o?void 0:o.preserveDrawingBuffer)===!1&&this.context.logger.warn("Unable to clone WebGL context as it has preserveDrawingBuffer=false",A)}n.drawImage(A,0,0)}}}catch(e){this.context.logger.info("Unable to clone canvas as it is tainted",A)}return r},A.prototype.createVideoClone=function(A){var e=A.ownerDocument.createElement("canvas");e.width=A.offsetWidth,e.height=A.offsetHeight;var t=e.getContext("2d");try{return t&&(t.drawImage(A,0,0,e.width,e.height),this.options.allowTaint||t.getImageData(0,0,e.width,e.height)),e}catch(e){this.context.logger.info("Unable to clone video as it is tainted",A)}var r=A.ownerDocument.createElement("canvas");return r.width=A.offsetWidth,r.height=A.offsetHeight,r},A.prototype.appendChildNode=function(A,e,t){(!r3(e)||"SCRIPT"!==e.tagName&&!e.hasAttribute(By)&&("function"!=typeof this.options.ignoreElements||!this.options.ignoreElements(e)))&&(this.options.copyStyles&&r3(e)&&Bs(e)||A.appendChild(this.cloneNode(e,t)))},A.prototype.cloneChildNodes=function(A,e,t){for(var r=this,B=A.shadowRoot?A.shadowRoot.firstChild:A.firstChild;B;B=B.nextSibling)if(r3(B)&&BQ(B)&&"function"==typeof B.assignedNodes){var n=B.assignedNodes();n.length&&n.forEach(function(A){return r.appendChildNode(e,A,t)})}else this.appendChildNode(e,B,t)},A.prototype.cloneNode=function(A,e){if(r2(A))return document.createTextNode(A.data);if(!A.ownerDocument)return A.cloneNode(!1);var t=A.ownerDocument.defaultView;if(t&&r3(A)&&(r5(A)||r6(A))){var r=this.createElementClone(A);r.style.transitionProperty="none";var B=t.getComputedStyle(A),n=t.getComputedStyle(A,":before"),s=t.getComputedStyle(A,":after");this.referenceElement===A&&r5(r)&&(this.clonedReferenceElement=r),Be(r)&&Bk(r);var o=this.counters.parse(new tz(this.context,B)),i=this.resolvePseudoContent(A,r,n,H.BEFORE);Ba(A)&&(e=!0),Br(A)||this.cloneChildNodes(A,r,e),i&&r.insertBefore(i,r.firstChild);var Q=this.resolvePseudoContent(A,r,s,H.AFTER);return Q&&r.appendChild(Q),this.counters.pop(o),(B&&(this.options.copyStyles||r6(A))&&!Bn(A)||e)&&Bx(B,r),(0!==A.scrollTop||0!==A.scrollLeft)&&this.scrolledElements.push([r,A.scrollLeft,A.scrollTop]),(Bo(A)||Bi(A))&&(Bo(r)||Bi(r))&&(r.value=A.value),r}return A.cloneNode(!1)},A.prototype.resolvePseudoContent=function(A,e,t,r){var B=this;if(t){var n=t.content,s=e.ownerDocument;if(s&&n&&"none"!==n&&"-moz-alt-content"!==n&&"none"!==t.display){this.counters.parse(new tz(this.context,t));var o=new tj(this.context,t),i=s.createElement("html2canvaspseudoelement");Bx(t,i),o.content.forEach(function(e){if(0===e.type)i.appendChild(s.createTextNode(e.value));else if(22===e.type){var t=s.createElement("img");t.src=e.value,t.style.opacity="1",i.appendChild(t)}else if(18===e.type){if("attr"===e.name){var r=e.values.filter(AN);r.length&&i.appendChild(s.createTextNode(A.getAttribute(r[0].value)||""))}else if("counter"===e.name){var n=e.values.filter(AY),Q=n[0],a=n[1];if(Q&&AN(Q)){var c=B.counters.getCounterValue(Q.value),g=a&&AN(a)?tn.parse(B.context,a.value):3;i.appendChild(s.createTextNode(BI(c,g,!1)))}}else if("counters"===e.name){var w=e.values.filter(AY),Q=w[0],l=w[1],a=w[2];if(Q&&AN(Q)){var U=B.counters.getCounterValues(Q.value),u=a&&AN(a)?tn.parse(B.context,a.value):3,C=l&&0===l.type?l.value:"",F=U.map(function(A){return BI(A,u,!1)}).join(C);i.appendChild(s.createTextNode(F))}}}else if(20===e.type)switch(e.value){case"open-quote":i.appendChild(s.createTextNode(tJ(o.quotes,B.quoteDepth++,!0)));break;case"close-quote":i.appendChild(s.createTextNode(tJ(o.quotes,--B.quoteDepth,!1)));break;default:i.appendChild(s.createTextNode(e.value))}}),i.className=BG+" "+BO;var Q=r===H.BEFORE?" "+BG:" "+BO;return r6(e)?e.className.baseValue+=Q:e.className+=Q,i}}},A.destroy=function(A){return!!A.parentNode&&(A.parentNode.removeChild(A),!0)},A}();(C=H||(H={}))[C.BEFORE=0]="BEFORE",C[C.AFTER=1]="AFTER";var Bm=function(A,e){var t=A.createElement("iframe");return t.className="html2canvas-container",t.style.visibility="hidden",t.style.position="fixed",t.style.left="-10000px",t.style.top="0px",t.style.border="0",t.width=e.width.toString(),t.height=e.height.toString(),t.scrolling="no",t.setAttribute(By,"true"),A.body.appendChild(t),t},BL=function(A){return new Promise(function(e){if(A.complete||!A.src){e();return}A.onload=e,A.onerror=e})},Bb=function(A){return Promise.all([].slice.call(A.images,0).map(BL))},Bv=function(A){return new Promise(function(e,t){var r=A.contentWindow;if(!r)return t("No window assigned for iframe");var B=r.document;r.onload=A.onload=function(){r.onload=A.onload=null;var t=setInterval(function(){B.body.childNodes.length>0&&"complete"===B.readyState&&(clearInterval(t),e(A))},50)}})},BD=["all","d","content"],Bx=function(A,e){for(var t=A.length-1;t>=0;t--){var r=A.item(t);-1===BD.indexOf(r)&&e.style.setProperty(r,A.getPropertyValue(r))}return e},BM=function(A){var e="";return A&&(e+="<!DOCTYPE ",A.name&&(e+=A.name),A.internalSubset&&(e+=A.internalSubset),A.publicId&&(e+='"'+A.publicId+'"'),A.systemId&&(e+='"'+A.systemId+'"'),e+=">"),e},BS=function(A,e,t){A&&A.defaultView&&(e!==A.defaultView.pageXOffset||t!==A.defaultView.pageYOffset)&&A.defaultView.scrollTo(e,t)},BT=function(A){var e=A[0],t=A[1],r=A[2];e.scrollLeft=t,e.scrollTop=r},BG="___html2canvas___pseudoelement_before",BO="___html2canvas___pseudoelement_after",BV='{\n    content: "" !important;\n    display: none !important;\n}',Bk=function(A){BR(A,"."+BG+":before"+BV+"\n         ."+BO+":after"+BV)},BR=function(A,e){var t=A.ownerDocument;if(t){var r=t.createElement("style");r.textContent=e,A.appendChild(r)}},BN=function(){function A(){}return A.getOrigin=function(e){var t=A._link;return t?(t.href=e,t.href=t.href,t.protocol+t.hostname+t.port):"about:blank"},A.isSameOrigin=function(e){return A.getOrigin(e)===A._origin},A.setContext=function(e){A._link=e.document.createElement("a"),A._origin=A.getOrigin(e.location.href)},A._origin="about:blank",A}(),BP=function(){function A(A,e){this.context=A,this._options=e,this._cache={}}return A.prototype.addImage=function(A){var e=Promise.resolve();return this.has(A)||(Bq(A)||BW(A))&&(this._cache[A]=this.loadImage(A)).catch(function(){}),e},A.prototype.match=function(A){return this._cache[A]},A.prototype.loadImage=function(A){return K(this,void 0,void 0,function(){var e,t,r,B,n=this;return m(this,function(s){switch(s.label){case 0:if(e=BN.isSameOrigin(A),t=!BZ(A)&&!0===this._options.useCORS&&rU.SUPPORT_CORS_IMAGES&&!e,r=!BZ(A)&&!e&&!Bq(A)&&"string"==typeof this._options.proxy&&rU.SUPPORT_CORS_XHR&&!t,!e&&!1===this._options.allowTaint&&!BZ(A)&&!Bq(A)&&!r&&!t)return[2];if(B=A,!r)return[3,2];return[4,this.proxy(B)];case 1:B=s.sent(),s.label=2;case 2:return this.context.logger.debug("Added image "+A.substring(0,256)),[4,new Promise(function(A,e){var r=new Image;r.onload=function(){return A(r)},r.onerror=e,(B_(B)||t)&&(r.crossOrigin="anonymous"),r.src=B,!0===r.complete&&setTimeout(function(){return A(r)},500),n._options.imageTimeout>0&&setTimeout(function(){return e("Timed out ("+n._options.imageTimeout+"ms) loading image")},n._options.imageTimeout)})];case 3:return[2,s.sent()]}})})},A.prototype.has=function(A){return void 0!==this._cache[A]},A.prototype.keys=function(){return Promise.resolve(Object.keys(this._cache))},A.prototype.proxy=function(A){var e=this,t=this._options.proxy;if(!t)throw Error("No proxy defined");var r=A.substring(0,256);return new Promise(function(B,n){var s=rU.SUPPORT_RESPONSE_TYPE?"blob":"text",o=new XMLHttpRequest;o.onload=function(){if(200===o.status){if("text"===s)B(o.response);else{var A=new FileReader;A.addEventListener("load",function(){return B(A.result)},!1),A.addEventListener("error",function(A){return n(A)},!1),A.readAsDataURL(o.response)}}else n("Failed to proxy resource "+r+" with status code "+o.status)},o.onerror=n;var i=t.indexOf("?")>-1?"&":"?";if(o.open("GET",""+t+i+"url="+encodeURIComponent(A)+"&responseType="+s),"text"!==s&&o instanceof XMLHttpRequest&&(o.responseType=s),e._options.imageTimeout){var Q=e._options.imageTimeout;o.timeout=Q,o.ontimeout=function(){return n("Timed out ("+Q+"ms) proxying "+r)}}o.send()})},A}(),BX=/^data:image\/svg\+xml/i,BJ=/^data:image\/.*;base64,/i,BY=/^data:image\/.*/i,BW=function(A){return rU.SUPPORT_SVG_DRAWING||!Bj(A)},BZ=function(A){return BY.test(A)},B_=function(A){return BJ.test(A)},Bq=function(A){return"blob"===A.substr(0,4)},Bj=function(A){return"svg"===A.substr(-3).toLowerCase()||BX.test(A)},Bz=function(){function A(A,e){this.type=0,this.x=A,this.y=e}return A.prototype.add=function(e,t){return new A(this.x+e,this.y+t)},A}(),B$=function(A,e,t){return new Bz(A.x+(e.x-A.x)*t,A.y+(e.y-A.y)*t)},B0=function(){function A(A,e,t,r){this.type=1,this.start=A,this.startControl=e,this.endControl=t,this.end=r}return A.prototype.subdivide=function(e,t){var r=B$(this.start,this.startControl,e),B=B$(this.startControl,this.endControl,e),n=B$(this.endControl,this.end,e),s=B$(r,B,e),o=B$(B,n,e),i=B$(s,o,e);return t?new A(this.start,r,s,i):new A(i,o,n,this.end)},A.prototype.add=function(e,t){return new A(this.start.add(e,t),this.startControl.add(e,t),this.endControl.add(e,t),this.end.add(e,t))},A.prototype.reverse=function(){return new A(this.end,this.endControl,this.startControl,this.start)},A}(),B4=function(A){return 1===A.type},B1=function(A){var e=A.styles,t=A.bounds,r=A4(e.borderTopLeftRadius,t.width,t.height),B=r[0],n=r[1],s=A4(e.borderTopRightRadius,t.width,t.height),o=s[0],i=s[1],Q=A4(e.borderBottomRightRadius,t.width,t.height),a=Q[0],c=Q[1],g=A4(e.borderBottomLeftRadius,t.width,t.height),w=g[0],l=g[1],U=[];U.push((B+o)/t.width),U.push((w+a)/t.width),U.push((n+l)/t.height),U.push((i+c)/t.height);var u=Math.max.apply(Math,U);u>1&&(B/=u,n/=u,o/=u,i/=u,a/=u,c/=u,w/=u,l/=u);var C=t.width-o,F=t.height-c,h=t.width-a,d=t.height-l,f=e.borderTopWidth,H=e.borderRightWidth,E=e.borderBottomWidth,I=e.borderLeftWidth,y=A1(e.paddingTop,A.bounds.width),K=A1(e.paddingRight,A.bounds.width),m=A1(e.paddingBottom,A.bounds.width),L=A1(e.paddingLeft,A.bounds.width);this.topLeftBorderDoubleOuterBox=B>0||n>0?B2(t.left+I/3,t.top+f/3,B-I/3,n-f/3,p.TOP_LEFT):new Bz(t.left+I/3,t.top+f/3),this.topRightBorderDoubleOuterBox=B>0||n>0?B2(t.left+C,t.top+f/3,o-H/3,i-f/3,p.TOP_RIGHT):new Bz(t.left+t.width-H/3,t.top+f/3),this.bottomRightBorderDoubleOuterBox=a>0||c>0?B2(t.left+h,t.top+F,a-H/3,c-E/3,p.BOTTOM_RIGHT):new Bz(t.left+t.width-H/3,t.top+t.height-E/3),this.bottomLeftBorderDoubleOuterBox=w>0||l>0?B2(t.left+I/3,t.top+d,w-I/3,l-E/3,p.BOTTOM_LEFT):new Bz(t.left+I/3,t.top+t.height-E/3),this.topLeftBorderDoubleInnerBox=B>0||n>0?B2(t.left+2*I/3,t.top+2*f/3,B-2*I/3,n-2*f/3,p.TOP_LEFT):new Bz(t.left+2*I/3,t.top+2*f/3),this.topRightBorderDoubleInnerBox=B>0||n>0?B2(t.left+C,t.top+2*f/3,o-2*H/3,i-2*f/3,p.TOP_RIGHT):new Bz(t.left+t.width-2*H/3,t.top+2*f/3),this.bottomRightBorderDoubleInnerBox=a>0||c>0?B2(t.left+h,t.top+F,a-2*H/3,c-2*E/3,p.BOTTOM_RIGHT):new Bz(t.left+t.width-2*H/3,t.top+t.height-2*E/3),this.bottomLeftBorderDoubleInnerBox=w>0||l>0?B2(t.left+2*I/3,t.top+d,w-2*I/3,l-2*E/3,p.BOTTOM_LEFT):new Bz(t.left+2*I/3,t.top+t.height-2*E/3),this.topLeftBorderStroke=B>0||n>0?B2(t.left+I/2,t.top+f/2,B-I/2,n-f/2,p.TOP_LEFT):new Bz(t.left+I/2,t.top+f/2),this.topRightBorderStroke=B>0||n>0?B2(t.left+C,t.top+f/2,o-H/2,i-f/2,p.TOP_RIGHT):new Bz(t.left+t.width-H/2,t.top+f/2),this.bottomRightBorderStroke=a>0||c>0?B2(t.left+h,t.top+F,a-H/2,c-E/2,p.BOTTOM_RIGHT):new Bz(t.left+t.width-H/2,t.top+t.height-E/2),this.bottomLeftBorderStroke=w>0||l>0?B2(t.left+I/2,t.top+d,w-I/2,l-E/2,p.BOTTOM_LEFT):new Bz(t.left+I/2,t.top+t.height-E/2),this.topLeftBorderBox=B>0||n>0?B2(t.left,t.top,B,n,p.TOP_LEFT):new Bz(t.left,t.top),this.topRightBorderBox=o>0||i>0?B2(t.left+C,t.top,o,i,p.TOP_RIGHT):new Bz(t.left+t.width,t.top),this.bottomRightBorderBox=a>0||c>0?B2(t.left+h,t.top+F,a,c,p.BOTTOM_RIGHT):new Bz(t.left+t.width,t.top+t.height),this.bottomLeftBorderBox=w>0||l>0?B2(t.left,t.top+d,w,l,p.BOTTOM_LEFT):new Bz(t.left,t.top+t.height),this.topLeftPaddingBox=B>0||n>0?B2(t.left+I,t.top+f,Math.max(0,B-I),Math.max(0,n-f),p.TOP_LEFT):new Bz(t.left+I,t.top+f),this.topRightPaddingBox=o>0||i>0?B2(t.left+Math.min(C,t.width-H),t.top+f,C>t.width+H?0:Math.max(0,o-H),Math.max(0,i-f),p.TOP_RIGHT):new Bz(t.left+t.width-H,t.top+f),this.bottomRightPaddingBox=a>0||c>0?B2(t.left+Math.min(h,t.width-I),t.top+Math.min(F,t.height-E),Math.max(0,a-H),Math.max(0,c-E),p.BOTTOM_RIGHT):new Bz(t.left+t.width-H,t.top+t.height-E),this.bottomLeftPaddingBox=w>0||l>0?B2(t.left+I,t.top+Math.min(d,t.height-E),Math.max(0,w-I),Math.max(0,l-E),p.BOTTOM_LEFT):new Bz(t.left+I,t.top+t.height-E),this.topLeftContentBox=B>0||n>0?B2(t.left+I+L,t.top+f+y,Math.max(0,B-(I+L)),Math.max(0,n-(f+y)),p.TOP_LEFT):new Bz(t.left+I+L,t.top+f+y),this.topRightContentBox=o>0||i>0?B2(t.left+Math.min(C,t.width+I+L),t.top+f+y,C>t.width+I+L?0:o-I+L,i-(f+y),p.TOP_RIGHT):new Bz(t.left+t.width-(H+K),t.top+f+y),this.bottomRightContentBox=a>0||c>0?B2(t.left+Math.min(h,t.width-(I+L)),t.top+Math.min(F,t.height+f+y),Math.max(0,a-(H+K)),c-(E+m),p.BOTTOM_RIGHT):new Bz(t.left+t.width-(H+K),t.top+t.height-(E+m)),this.bottomLeftContentBox=w>0||l>0?B2(t.left+I+L,t.top+d,Math.max(0,w-(I+L)),l-(E+m),p.BOTTOM_LEFT):new Bz(t.left+I+L,t.top+t.height-(E+m))};(F=p||(p={}))[F.TOP_LEFT=0]="TOP_LEFT",F[F.TOP_RIGHT=1]="TOP_RIGHT",F[F.BOTTOM_RIGHT=2]="BOTTOM_RIGHT",F[F.BOTTOM_LEFT=3]="BOTTOM_LEFT";var B2=function(A,e,t,r,B){var n=(Math.sqrt(2)-1)/3*4,s=t*n,o=r*n,i=A+t,Q=e+r;switch(B){case p.TOP_LEFT:return new B0(new Bz(A,Q),new Bz(A,Q-o),new Bz(i-s,e),new Bz(i,e));case p.TOP_RIGHT:return new B0(new Bz(A,e),new Bz(A+s,e),new Bz(i,Q-o),new Bz(i,Q));case p.BOTTOM_RIGHT:return new B0(new Bz(i,e),new Bz(i,e+o),new Bz(A+s,Q),new Bz(A,Q));case p.BOTTOM_LEFT:default:return new B0(new Bz(i,Q),new Bz(i-s,Q),new Bz(A,e+o),new Bz(A,e))}},B3=function(A){return[A.topLeftBorderBox,A.topRightBorderBox,A.bottomRightBorderBox,A.bottomLeftBorderBox]},B5=function(A){return[A.topLeftPaddingBox,A.topRightPaddingBox,A.bottomRightPaddingBox,A.bottomLeftPaddingBox]},B6=function(A,e,t){this.offsetX=A,this.offsetY=e,this.matrix=t,this.type=0,this.target=6},B8=function(A,e){this.path=A,this.target=e,this.type=1},B9=function(A){this.opacity=A,this.type=2,this.target=6},B7=function(A){return 1===A.type},nA=function(A,e){return A.length===e.length&&A.some(function(A,t){return A===e[t]})},ne=function(A){this.element=A,this.inlineLevel=[],this.nonInlineLevel=[],this.negativeZIndex=[],this.zeroOrAutoZIndexOrTransformedOrOpacity=[],this.positiveZIndex=[],this.nonPositionedFloats=[],this.nonPositionedInlineLevel=[]},nt=function(){function A(A,e){if(this.container=A,this.parent=e,this.effects=[],this.curves=new B1(this.container),this.container.styles.opacity<1&&this.effects.push(new B9(this.container.styles.opacity)),null!==this.container.styles.transform){var t=this.container.bounds.left+this.container.styles.transformOrigin[0].number,r=this.container.bounds.top+this.container.styles.transformOrigin[1].number,B=this.container.styles.transform;this.effects.push(new B6(t,r,B))}if(0!==this.container.styles.overflowX){var n=B3(this.curves),s=B5(this.curves);nA(n,s)?this.effects.push(new B8(n,6)):(this.effects.push(new B8(n,2)),this.effects.push(new B8(s,4)))}}return A.prototype.getEffects=function(A){for(var e=-1===[2,3].indexOf(this.container.styles.position),t=this.parent,r=this.effects.slice(0);t;){var B=t.effects.filter(function(A){return!B7(A)});if(e||0!==t.container.styles.position||!t.parent){if(r.unshift.apply(r,B),e=-1===[2,3].indexOf(t.container.styles.position),0!==t.container.styles.overflowX){var n=B3(t.curves),s=B5(t.curves);nA(n,s)||r.unshift(new B8(s,6))}}else r.unshift.apply(r,B);t=t.parent}return r.filter(function(e){return tV(e.target,A)})},A}(),nr=function(A,e,t,r){A.container.elements.forEach(function(B){var n=tV(B.flags,4),s=tV(B.flags,2),o=new nt(B,A);tV(B.styles.display,2048)&&r.push(o);var i=tV(B.flags,8)?[]:r;if(n||s){var Q=n||B.styles.isPositioned()?t:e,a=new ne(o);if(B.styles.isPositioned()||B.styles.opacity<1||B.styles.isTransformed()){var c=B.styles.zIndex.order;if(c<0){var g=0;Q.negativeZIndex.some(function(A,e){if(c>A.element.container.styles.zIndex.order)g=e;else if(g>0)return!0;return!1}),Q.negativeZIndex.splice(g,0,a)}else if(c>0){var w=0;Q.positiveZIndex.some(function(A,e){if(c>=A.element.container.styles.zIndex.order)w=e+1;else if(w>0)return!0;return!1}),Q.positiveZIndex.splice(w,0,a)}else Q.zeroOrAutoZIndexOrTransformedOrOpacity.push(a)}else B.styles.isFloating()?Q.nonPositionedFloats.push(a):Q.nonPositionedInlineLevel.push(a);nr(o,a,n?a:t,i)}else B.styles.isInlineLevel()?e.inlineLevel.push(o):e.nonInlineLevel.push(o),nr(o,e,t,i);tV(B.flags,8)&&nB(B,i)})},nB=function(A,e){for(var t=A instanceof rk?A.start:1,r=A instanceof rk&&A.reversed,B=0;B<e.length;B++){var n=e[B];n.container instanceof rV&&"number"==typeof n.container.value&&0!==n.container.value&&(t=n.container.value),n.listValue=BI(t,n.container.styles.listStyleType,!0),t+=r?-1:1}},nn=function(A){var e=new nt(A,null),t=new ne(e),r=[];return nr(e,t,t,r),nB(e.container,r),t},ns=function(A,e){switch(e){case 0:return nc(A.topLeftBorderBox,A.topLeftPaddingBox,A.topRightBorderBox,A.topRightPaddingBox);case 1:return nc(A.topRightBorderBox,A.topRightPaddingBox,A.bottomRightBorderBox,A.bottomRightPaddingBox);case 2:return nc(A.bottomRightBorderBox,A.bottomRightPaddingBox,A.bottomLeftBorderBox,A.bottomLeftPaddingBox);default:return nc(A.bottomLeftBorderBox,A.bottomLeftPaddingBox,A.topLeftBorderBox,A.topLeftPaddingBox)}},no=function(A,e){switch(e){case 0:return nc(A.topLeftBorderBox,A.topLeftBorderDoubleOuterBox,A.topRightBorderBox,A.topRightBorderDoubleOuterBox);case 1:return nc(A.topRightBorderBox,A.topRightBorderDoubleOuterBox,A.bottomRightBorderBox,A.bottomRightBorderDoubleOuterBox);case 2:return nc(A.bottomRightBorderBox,A.bottomRightBorderDoubleOuterBox,A.bottomLeftBorderBox,A.bottomLeftBorderDoubleOuterBox);default:return nc(A.bottomLeftBorderBox,A.bottomLeftBorderDoubleOuterBox,A.topLeftBorderBox,A.topLeftBorderDoubleOuterBox)}},ni=function(A,e){switch(e){case 0:return nc(A.topLeftBorderDoubleInnerBox,A.topLeftPaddingBox,A.topRightBorderDoubleInnerBox,A.topRightPaddingBox);case 1:return nc(A.topRightBorderDoubleInnerBox,A.topRightPaddingBox,A.bottomRightBorderDoubleInnerBox,A.bottomRightPaddingBox);case 2:return nc(A.bottomRightBorderDoubleInnerBox,A.bottomRightPaddingBox,A.bottomLeftBorderDoubleInnerBox,A.bottomLeftPaddingBox);default:return nc(A.bottomLeftBorderDoubleInnerBox,A.bottomLeftPaddingBox,A.topLeftBorderDoubleInnerBox,A.topLeftPaddingBox)}},nQ=function(A,e){switch(e){case 0:return na(A.topLeftBorderStroke,A.topRightBorderStroke);case 1:return na(A.topRightBorderStroke,A.bottomRightBorderStroke);case 2:return na(A.bottomRightBorderStroke,A.bottomLeftBorderStroke);default:return na(A.bottomLeftBorderStroke,A.topLeftBorderStroke)}},na=function(A,e){var t=[];return B4(A)?t.push(A.subdivide(.5,!1)):t.push(A),B4(e)?t.push(e.subdivide(.5,!0)):t.push(e),t},nc=function(A,e,t,r){var B=[];return B4(A)?B.push(A.subdivide(.5,!1)):B.push(A),B4(t)?B.push(t.subdivide(.5,!0)):B.push(t),B4(r)?B.push(r.subdivide(.5,!0).reverse()):B.push(r),B4(e)?B.push(e.subdivide(.5,!1).reverse()):B.push(e),B},ng=function(A){var e=A.bounds,t=A.styles;return e.add(t.borderLeftWidth,t.borderTopWidth,-(t.borderRightWidth+t.borderLeftWidth),-(t.borderTopWidth+t.borderBottomWidth))},nw=function(A){var e=A.styles,t=A.bounds,r=A1(e.paddingLeft,t.width),B=A1(e.paddingRight,t.width),n=A1(e.paddingTop,t.width),s=A1(e.paddingBottom,t.width);return t.add(r+e.borderLeftWidth,n+e.borderTopWidth,-(e.borderRightWidth+e.borderLeftWidth+r+B),-(e.borderTopWidth+e.borderBottomWidth+n+s))},nl=function(A,e,t){var r,B,n=0===(r=nF(A.styles.backgroundOrigin,e))?A.bounds:2===r?nw(A):ng(A),s=0===(B=nF(A.styles.backgroundClip,e))?A.bounds:2===B?nw(A):ng(A),o=nC(nF(A.styles.backgroundSize,e),t,n),i=o[0],Q=o[1],a=A4(nF(A.styles.backgroundPosition,e),n.width-i,n.height-Q);return[nh(nF(A.styles.backgroundRepeat,e),a,o,n,s),Math.round(n.left+a[0]),Math.round(n.top+a[1]),i,Q]},nU=function(A){return AN(A)&&A.value===h.AUTO},nu=function(A){return"number"==typeof A},nC=function(A,e,t){var r=e[0],B=e[1],n=e[2],s=A[0],o=A[1];if(!s)return[0,0];if(Aq(s)&&o&&Aq(o))return[A1(s,t.width),A1(o,t.height)];var i=nu(n);if(AN(s)&&(s.value===h.CONTAIN||s.value===h.COVER))return nu(n)?t.width/t.height<n!=(s.value===h.COVER)?[t.width,t.width/n]:[t.height*n,t.height]:[t.width,t.height];var Q=nu(r),a=nu(B),c=Q||a;if(nU(s)&&(!o||nU(o)))return Q&&a?[r,B]:i||c?c&&i?[Q?r:B*n,a?B:r/n]:[Q?r:t.width,a?B:t.height]:[t.width,t.height];if(i){var g=0,w=0;return Aq(s)?g=A1(s,t.width):Aq(o)&&(w=A1(o,t.height)),nU(s)?g=w*n:(!o||nU(o))&&(w=g/n),[g,w]}var l=null,U=null;if(Aq(s)?l=A1(s,t.width):o&&Aq(o)&&(U=A1(o,t.height)),null!==l&&(!o||nU(o))&&(U=Q&&a?l/r*B:t.height),null!==U&&nU(s)&&(l=Q&&a?U/B*r:t.width),null!==l&&null!==U)return[l,U];throw Error("Unable to calculate background-size for element")},nF=function(A,e){var t=A[e];return void 0===t?A[0]:t},nh=function(A,e,t,r,B){var n=e[0],s=e[1],o=t[0],i=t[1];switch(A){case 2:return[new Bz(Math.round(r.left),Math.round(r.top+s)),new Bz(Math.round(r.left+r.width),Math.round(r.top+s)),new Bz(Math.round(r.left+r.width),Math.round(i+r.top+s)),new Bz(Math.round(r.left),Math.round(i+r.top+s))];case 3:return[new Bz(Math.round(r.left+n),Math.round(r.top)),new Bz(Math.round(r.left+n+o),Math.round(r.top)),new Bz(Math.round(r.left+n+o),Math.round(r.height+r.top)),new Bz(Math.round(r.left+n),Math.round(r.height+r.top))];case 1:return[new Bz(Math.round(r.left+n),Math.round(r.top+s)),new Bz(Math.round(r.left+n+o),Math.round(r.top+s)),new Bz(Math.round(r.left+n+o),Math.round(r.top+s+i)),new Bz(Math.round(r.left+n),Math.round(r.top+s+i))];default:return[new Bz(Math.round(B.left),Math.round(B.top)),new Bz(Math.round(B.left+B.width),Math.round(B.top)),new Bz(Math.round(B.left+B.width),Math.round(B.height+B.top)),new Bz(Math.round(B.left),Math.round(B.height+B.top))]}},nd="Hidden Text",nf=function(){function A(A){this._data={},this._document=A}return A.prototype.parseMetrics=function(A,e){var t=this._document.createElement("div"),r=this._document.createElement("img"),B=this._document.createElement("span"),n=this._document.body;t.style.visibility="hidden",t.style.fontFamily=A,t.style.fontSize=e,t.style.margin="0",t.style.padding="0",t.style.whiteSpace="nowrap",n.appendChild(t),r.src="data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7",r.width=1,r.height=1,r.style.margin="0",r.style.padding="0",r.style.verticalAlign="baseline",B.style.fontFamily=A,B.style.fontSize=e,B.style.margin="0",B.style.padding="0",B.appendChild(this._document.createTextNode(nd)),t.appendChild(B),t.appendChild(r);var s=r.offsetTop-B.offsetTop+2;t.removeChild(B),t.appendChild(this._document.createTextNode(nd)),t.style.lineHeight="normal",r.style.verticalAlign="super";var o=r.offsetTop-t.offsetTop+2;return n.removeChild(t),{baseline:s,middle:o}},A.prototype.getMetrics=function(A,e){var t=A+" "+e;return void 0===this._data[t]&&(this._data[t]=this.parseMetrics(A,e)),this._data[t]},A}(),nH=function(A,e){this.context=A,this.options=e},np=function(A){function e(e,t){var r=A.call(this,e,t)||this;return r._activeEffects=[],r.canvas=t.canvas?t.canvas:document.createElement("canvas"),r.ctx=r.canvas.getContext("2d"),t.canvas||(r.canvas.width=Math.floor(t.width*t.scale),r.canvas.height=Math.floor(t.height*t.scale),r.canvas.style.width=t.width+"px",r.canvas.style.height=t.height+"px"),r.fontMetrics=new nf(document),r.ctx.scale(r.options.scale,r.options.scale),r.ctx.translate(-t.x,-t.y),r.ctx.textBaseline="bottom",r._activeEffects=[],r.context.logger.debug("Canvas renderer initialized ("+t.width+"x"+t.height+") with scale "+t.scale),r}return I(e,A),e.prototype.applyEffects=function(A){for(var e=this;this._activeEffects.length;)this.popEffect();A.forEach(function(A){return e.applyEffect(A)})},e.prototype.applyEffect=function(A){this.ctx.save(),2===A.type&&(this.ctx.globalAlpha=A.opacity),0===A.type&&(this.ctx.translate(A.offsetX,A.offsetY),this.ctx.transform(A.matrix[0],A.matrix[1],A.matrix[2],A.matrix[3],A.matrix[4],A.matrix[5]),this.ctx.translate(-A.offsetX,-A.offsetY)),B7(A)&&(this.path(A.path),this.ctx.clip()),this._activeEffects.push(A)},e.prototype.popEffect=function(){this._activeEffects.pop(),this.ctx.restore()},e.prototype.renderStack=function(A){return K(this,void 0,void 0,function(){return m(this,function(e){switch(e.label){case 0:if(!A.element.container.styles.isVisible())return[3,2];return[4,this.renderStackContent(A)];case 1:e.sent(),e.label=2;case 2:return[2]}})})},e.prototype.renderNode=function(A){return K(this,void 0,void 0,function(){return m(this,function(e){switch(e.label){case 0:if(tV(A.container.flags,16),!A.container.styles.isVisible())return[3,3];return[4,this.renderNodeBackgroundAndBorders(A)];case 1:return e.sent(),[4,this.renderNodeContent(A)];case 2:e.sent(),e.label=3;case 3:return[2]}})})},e.prototype.renderTextWithLetterSpacing=function(A,e,t){var r=this;0===e?this.ctx.fillText(A.text,A.bounds.left,A.bounds.top+t):rm(A.text).reduce(function(e,B){return r.ctx.fillText(B,e,A.bounds.top+t),e+r.ctx.measureText(B).width},A.bounds.left)},e.prototype.createFontStyle=function(A){var e=A.fontVariant.filter(function(A){return"normal"===A||"small-caps"===A}).join(""),t=nm(A.fontFamily).join(", "),r=Ak(A.fontSize)?""+A.fontSize.number+A.fontSize.unit:A.fontSize.number+"px";return[[A.fontStyle,e,A.fontWeight,r,t].join(" "),t,r]},e.prototype.renderTextNode=function(A,e){return K(this,void 0,void 0,function(){var t,r,B,n,s,o,i,Q,a=this;return m(this,function(c){return r=(t=this.createFontStyle(e))[0],B=t[1],n=t[2],this.ctx.font=r,this.ctx.direction=1===e.direction?"rtl":"ltr",this.ctx.textAlign="left",this.ctx.textBaseline="alphabetic",o=(s=this.fontMetrics.getMetrics(B,n)).baseline,i=s.middle,Q=e.paintOrder,A.textBounds.forEach(function(A){Q.forEach(function(t){switch(t){case 0:a.ctx.fillStyle=ee(e.color),a.renderTextWithLetterSpacing(A,e.letterSpacing,o);var r=e.textShadow;r.length&&A.text.trim().length&&(r.slice(0).reverse().forEach(function(t){a.ctx.shadowColor=ee(t.color),a.ctx.shadowOffsetX=t.offsetX.number*a.options.scale,a.ctx.shadowOffsetY=t.offsetY.number*a.options.scale,a.ctx.shadowBlur=t.blur.number,a.renderTextWithLetterSpacing(A,e.letterSpacing,o)}),a.ctx.shadowColor="",a.ctx.shadowOffsetX=0,a.ctx.shadowOffsetY=0,a.ctx.shadowBlur=0),e.textDecorationLine.length&&(a.ctx.fillStyle=ee(e.textDecorationColor||e.color),e.textDecorationLine.forEach(function(e){switch(e){case 1:a.ctx.fillRect(A.bounds.left,Math.round(A.bounds.top+o),A.bounds.width,1);break;case 2:a.ctx.fillRect(A.bounds.left,Math.round(A.bounds.top),A.bounds.width,1);break;case 3:a.ctx.fillRect(A.bounds.left,Math.ceil(A.bounds.top+i),A.bounds.width,1)}}));break;case 1:e.webkitTextStrokeWidth&&A.text.trim().length&&(a.ctx.strokeStyle=ee(e.webkitTextStrokeColor),a.ctx.lineWidth=e.webkitTextStrokeWidth,a.ctx.lineJoin=window.chrome?"miter":"round",a.ctx.strokeText(A.text,A.bounds.left,A.bounds.top+o)),a.ctx.strokeStyle="",a.ctx.lineWidth=0,a.ctx.lineJoin="miter"}})}),[2]})})},e.prototype.renderReplacedElement=function(A,e,t){if(t&&A.intrinsicWidth>0&&A.intrinsicHeight>0){var r=nw(A),B=B5(e);this.path(B),this.ctx.save(),this.ctx.clip(),this.ctx.drawImage(t,0,0,A.intrinsicWidth,A.intrinsicHeight,r.left,r.top,r.width,r.height),this.ctx.restore()}},e.prototype.renderNodeContent=function(A){return K(this,void 0,void 0,function(){var t,r,B,n,s,o,i,Q,a,c,g,w,l,U,u,C,F,h;return m(this,function(d){switch(d.label){case 0:this.applyEffects(A.getEffects(4)),t=A.container,r=A.curves,B=t.styles,n=0,s=t.textNodes,d.label=1;case 1:if(!(n<s.length))return[3,4];return o=s[n],[4,this.renderTextNode(o,B)];case 2:d.sent(),d.label=3;case 3:return n++,[3,1];case 4:if(!(t instanceof rT))return[3,8];d.label=5;case 5:return d.trys.push([5,7,,8]),[4,this.context.cache.match(t.src)];case 6:return i=d.sent(),this.renderReplacedElement(t,r,i),[3,8];case 7:return d.sent(),this.context.logger.error("Error loading image "+t.src),[3,8];case 8:if(t instanceof rG&&this.renderReplacedElement(t,r,t.canvas),!(t instanceof rO))return[3,12];d.label=9;case 9:return d.trys.push([9,11,,12]),[4,this.context.cache.match(t.svg)];case 10:return i=d.sent(),this.renderReplacedElement(t,r,i),[3,12];case 11:return d.sent(),this.context.logger.error("Error loading svg "+t.svg.substring(0,255)),[3,12];case 12:if(!(t instanceof rq&&t.tree))return[3,14];return[4,new e(this.context,{scale:this.options.scale,backgroundColor:t.backgroundColor,x:0,y:0,width:t.width,height:t.height}).render(t.tree)];case 13:Q=d.sent(),t.width&&t.height&&this.ctx.drawImage(Q,0,0,t.width,t.height,t.bounds.left,t.bounds.top,t.bounds.width,t.bounds.height),d.label=14;case 14:if(t instanceof rW&&(a=Math.min(t.bounds.width,t.bounds.height),t.type===rX?t.checked&&(this.ctx.save(),this.path([new Bz(t.bounds.left+.39363*a,t.bounds.top+.79*a),new Bz(t.bounds.left+.16*a,t.bounds.top+.5549*a),new Bz(t.bounds.left+.27347*a,t.bounds.top+.44071*a),new Bz(t.bounds.left+.39694*a,t.bounds.top+.5649*a),new Bz(t.bounds.left+.72983*a,t.bounds.top+.23*a),new Bz(t.bounds.left+.84*a,t.bounds.top+.34085*a),new Bz(t.bounds.left+.39363*a,t.bounds.top+.79*a)]),this.ctx.fillStyle=ee(707406591),this.ctx.fill(),this.ctx.restore()):t.type===rJ&&t.checked&&(this.ctx.save(),this.ctx.beginPath(),this.ctx.arc(t.bounds.left+a/2,t.bounds.top+a/2,a/4,0,2*Math.PI,!0),this.ctx.fillStyle=ee(707406591),this.ctx.fill(),this.ctx.restore())),nE(t)&&t.value.length){switch(g=(c=this.createFontStyle(B))[0],w=c[1],l=this.fontMetrics.getMetrics(g,w).baseline,this.ctx.font=g,this.ctx.fillStyle=ee(B.color),this.ctx.textBaseline="alphabetic",this.ctx.textAlign=ny(t.styles.textAlign),U=nw(t),u=0,t.styles.textAlign){case 1:u+=U.width/2;break;case 2:u+=U.width}C=U.add(u,0,0,-U.height/2+1),this.ctx.save(),this.path([new Bz(U.left,U.top),new Bz(U.left+U.width,U.top),new Bz(U.left+U.width,U.top+U.height),new Bz(U.left,U.top+U.height)]),this.ctx.clip(),this.renderTextWithLetterSpacing(new rE(t.value,C),B.letterSpacing,l),this.ctx.restore(),this.ctx.textBaseline="alphabetic",this.ctx.textAlign="left"}if(!tV(t.styles.display,2048))return[3,20];if(!(null!==t.styles.listStyleImage))return[3,19];if(0!==(F=t.styles.listStyleImage).type)return[3,18];i=void 0,h=F.url,d.label=15;case 15:return d.trys.push([15,17,,18]),[4,this.context.cache.match(h)];case 16:return i=d.sent(),this.ctx.drawImage(i,t.bounds.left-(i.width+10),t.bounds.top),[3,18];case 17:return d.sent(),this.context.logger.error("Error loading list-style-image "+h),[3,18];case 18:return[3,20];case 19:A.listValue&&-1!==t.styles.listStyleType&&(g=this.createFontStyle(B)[0],this.ctx.font=g,this.ctx.fillStyle=ee(B.color),this.ctx.textBaseline="middle",this.ctx.textAlign="right",U=new b(t.bounds.left,t.bounds.top+A1(t.styles.paddingTop,t.bounds.width),t.bounds.width,tt(B.lineHeight,B.fontSize.number)/2+1),this.renderTextWithLetterSpacing(new rE(A.listValue,U),B.letterSpacing,tt(B.lineHeight,B.fontSize.number)/2+2),this.ctx.textBaseline="bottom",this.ctx.textAlign="left"),d.label=20;case 20:return[2]}})})},e.prototype.renderStackContent=function(A){return K(this,void 0,void 0,function(){var e,t,r,B,n,s,o,i,Q,a,c,g,w,l,U;return m(this,function(u){switch(u.label){case 0:return tV(A.element.container.flags,16),[4,this.renderNodeBackgroundAndBorders(A.element)];case 1:u.sent(),e=0,t=A.negativeZIndex,u.label=2;case 2:if(!(e<t.length))return[3,5];return r=t[e],[4,this.renderStack(r)];case 3:u.sent(),u.label=4;case 4:return e++,[3,2];case 5:return[4,this.renderNodeContent(A.element)];case 6:u.sent(),B=0,n=A.nonInlineLevel,u.label=7;case 7:if(!(B<n.length))return[3,10];return r=n[B],[4,this.renderNode(r)];case 8:u.sent(),u.label=9;case 9:return B++,[3,7];case 10:s=0,o=A.nonPositionedFloats,u.label=11;case 11:if(!(s<o.length))return[3,14];return r=o[s],[4,this.renderStack(r)];case 12:u.sent(),u.label=13;case 13:return s++,[3,11];case 14:i=0,Q=A.nonPositionedInlineLevel,u.label=15;case 15:if(!(i<Q.length))return[3,18];return r=Q[i],[4,this.renderStack(r)];case 16:u.sent(),u.label=17;case 17:return i++,[3,15];case 18:a=0,c=A.inlineLevel,u.label=19;case 19:if(!(a<c.length))return[3,22];return r=c[a],[4,this.renderNode(r)];case 20:u.sent(),u.label=21;case 21:return a++,[3,19];case 22:g=0,w=A.zeroOrAutoZIndexOrTransformedOrOpacity,u.label=23;case 23:if(!(g<w.length))return[3,26];return r=w[g],[4,this.renderStack(r)];case 24:u.sent(),u.label=25;case 25:return g++,[3,23];case 26:l=0,U=A.positiveZIndex,u.label=27;case 27:if(!(l<U.length))return[3,30];return r=U[l],[4,this.renderStack(r)];case 28:u.sent(),u.label=29;case 29:return l++,[3,27];case 30:return[2]}})})},e.prototype.mask=function(A){this.ctx.beginPath(),this.ctx.moveTo(0,0),this.ctx.lineTo(this.canvas.width,0),this.ctx.lineTo(this.canvas.width,this.canvas.height),this.ctx.lineTo(0,this.canvas.height),this.ctx.lineTo(0,0),this.formatPath(A.slice(0).reverse()),this.ctx.closePath()},e.prototype.path=function(A){this.ctx.beginPath(),this.formatPath(A),this.ctx.closePath()},e.prototype.formatPath=function(A){var e=this;A.forEach(function(A,t){var r=B4(A)?A.start:A;0===t?e.ctx.moveTo(r.x,r.y):e.ctx.lineTo(r.x,r.y),B4(A)&&e.ctx.bezierCurveTo(A.startControl.x,A.startControl.y,A.endControl.x,A.endControl.y,A.end.x,A.end.y)})},e.prototype.renderRepeat=function(A,e,t,r){this.path(A),this.ctx.fillStyle=e,this.ctx.translate(t,r),this.ctx.fill(),this.ctx.translate(-t,-r)},e.prototype.resizeImage=function(A,e,t){if(A.width===e&&A.height===t)return A;var r,B=(null!==(r=this.canvas.ownerDocument)&&void 0!==r?r:document).createElement("canvas");return B.width=Math.max(1,e),B.height=Math.max(1,t),B.getContext("2d").drawImage(A,0,0,A.width,A.height,0,0,e,t),B},e.prototype.renderBackgroundImage=function(A){return K(this,void 0,void 0,function(){var e,t,r,B,n,s;return m(this,function(o){switch(o.label){case 0:e=A.styles.backgroundImage.length-1,t=function(t){var B,n,s,o,i,Q,a,c,g,w,l,U,u,C,F,h,d,f,H,p,E,I,y,K,L,b,v,D,x,M,S;return m(this,function(m){switch(m.label){case 0:if(0!==t.type)return[3,5];B=void 0,n=t.url,m.label=1;case 1:return m.trys.push([1,3,,4]),[4,r.context.cache.match(n)];case 2:return B=m.sent(),[3,4];case 3:return m.sent(),r.context.logger.error("Error loading background-image "+n),[3,4];case 4:return B&&(o=(s=nl(A,e,[B.width,B.height,B.width/B.height]))[0],i=s[1],Q=s[2],a=s[3],c=s[4],g=r.ctx.createPattern(r.resizeImage(B,a,c),"repeat"),r.renderRepeat(o,g,i,Q)),[3,6];case 5:1===t.type?(o=(w=nl(A,e,[null,null,null]))[0],i=w[1],Q=w[2],a=w[3],c=w[4],U=(l=eU(t.angle,a,c))[0],u=l[1],C=l[2],F=l[3],h=l[4],(d=document.createElement("canvas")).width=a,d.height=c,H=(f=d.getContext("2d")).createLinearGradient(u,F,C,h),ew(t.stops,U).forEach(function(A){return H.addColorStop(A.stop,ee(A.color))}),f.fillStyle=H,f.fillRect(0,0,a,c),a>0&&c>0&&(g=r.ctx.createPattern(d,"repeat"),r.renderRepeat(o,g,i,Q))):2===t.type&&(o=(p=nl(A,e,[null,null,null]))[0],E=p[1],I=p[2],a=p[3],c=p[4],i=A1((y=0===t.position.length?[A$]:t.position)[0],a),Q=A1(y[y.length-1],c),L=(K=eF(t,i,Q,a,c))[0],b=K[1],L>0&&b>0&&(v=r.ctx.createRadialGradient(E+i,I+Q,0,E+i,I+Q,L),ew(t.stops,2*L).forEach(function(A){return v.addColorStop(A.stop,ee(A.color))}),r.path(o),r.ctx.fillStyle=v,L!==b?(D=A.bounds.left+.5*A.bounds.width,x=A.bounds.top+.5*A.bounds.height,S=1/(M=b/L),r.ctx.save(),r.ctx.translate(D,x),r.ctx.transform(1,0,0,M,0,0),r.ctx.translate(-D,-x),r.ctx.fillRect(E,S*(I-x)+x,a,c*S),r.ctx.restore()):r.ctx.fill())),m.label=6;case 6:return e--,[2]}})},r=this,B=0,n=A.styles.backgroundImage.slice(0).reverse(),o.label=1;case 1:if(!(B<n.length))return[3,4];return s=n[B],[5,t(s)];case 2:o.sent(),o.label=3;case 3:return B++,[3,1];case 4:return[2]}})})},e.prototype.renderSolidBorder=function(A,e,t){return K(this,void 0,void 0,function(){return m(this,function(r){return this.path(ns(t,e)),this.ctx.fillStyle=ee(A),this.ctx.fill(),[2]})})},e.prototype.renderDoubleBorder=function(A,e,t,r){return K(this,void 0,void 0,function(){var B,n;return m(this,function(s){switch(s.label){case 0:if(!(e<3))return[3,2];return[4,this.renderSolidBorder(A,t,r)];case 1:return s.sent(),[2];case 2:return B=no(r,t),this.path(B),this.ctx.fillStyle=ee(A),this.ctx.fill(),n=ni(r,t),this.path(n),this.ctx.fill(),[2]}})})},e.prototype.renderNodeBackgroundAndBorders=function(A){return K(this,void 0,void 0,function(){var e,t,r,B,n,s,o,i,Q=this;return m(this,function(a){switch(a.label){case 0:if(this.applyEffects(A.getEffects(2)),t=!eA((e=A.container.styles).backgroundColor)||e.backgroundImage.length,r=[{style:e.borderTopStyle,color:e.borderTopColor,width:e.borderTopWidth},{style:e.borderRightStyle,color:e.borderRightColor,width:e.borderRightWidth},{style:e.borderBottomStyle,color:e.borderBottomColor,width:e.borderBottomWidth},{style:e.borderLeftStyle,color:e.borderLeftColor,width:e.borderLeftWidth}],B=nI(nF(e.backgroundClip,0),A.curves),!(t||e.boxShadow.length))return[3,2];return this.ctx.save(),this.path(B),this.ctx.clip(),eA(e.backgroundColor)||(this.ctx.fillStyle=ee(e.backgroundColor),this.ctx.fill()),[4,this.renderBackgroundImage(A.container)];case 1:a.sent(),this.ctx.restore(),e.boxShadow.slice(0).reverse().forEach(function(e){Q.ctx.save();var t,r,B,n,s=B3(A.curves),o=e.inset?0:1e4,i=(t=-o+(e.inset?1:-1)*e.spread.number,r=(e.inset?1:-1)*e.spread.number,B=e.spread.number*(e.inset?-2:2),n=e.spread.number*(e.inset?-2:2),s.map(function(A,e){switch(e){case 0:return A.add(t,r);case 1:return A.add(t+B,r);case 2:return A.add(t+B,r+n);case 3:return A.add(t,r+n)}return A}));e.inset?(Q.path(s),Q.ctx.clip(),Q.mask(i)):(Q.mask(s),Q.ctx.clip(),Q.path(i)),Q.ctx.shadowOffsetX=e.offsetX.number+o,Q.ctx.shadowOffsetY=e.offsetY.number,Q.ctx.shadowColor=ee(e.color),Q.ctx.shadowBlur=e.blur.number,Q.ctx.fillStyle=e.inset?ee(e.color):"rgba(0,0,0,1)",Q.ctx.fill(),Q.ctx.restore()}),a.label=2;case 2:n=0,s=0,o=r,a.label=3;case 3:if(!(s<o.length))return[3,13];if(!(0!==(i=o[s]).style&&!eA(i.color)&&i.width>0))return[3,11];if(2!==i.style)return[3,5];return[4,this.renderDashedDottedBorder(i.color,i.width,n,A.curves,2)];case 4:case 6:case 8:return a.sent(),[3,11];case 5:if(3!==i.style)return[3,7];return[4,this.renderDashedDottedBorder(i.color,i.width,n,A.curves,3)];case 7:if(4!==i.style)return[3,9];return[4,this.renderDoubleBorder(i.color,i.width,n,A.curves)];case 9:return[4,this.renderSolidBorder(i.color,n,A.curves)];case 10:a.sent(),a.label=11;case 11:n++,a.label=12;case 12:return s++,[3,3];case 13:return[2]}})})},e.prototype.renderDashedDottedBorder=function(A,e,t,r,B){return K(this,void 0,void 0,function(){var n,s,o,i,Q,a,c,g,w,l,U,u,C,F,h,d;return m(this,function(f){return this.ctx.save(),n=nQ(r,t),s=ns(r,t),2===B&&(this.path(s),this.ctx.clip()),B4(s[0])?(o=s[0].start.x,i=s[0].start.y):(o=s[0].x,i=s[0].y),B4(s[1])?(Q=s[1].end.x,a=s[1].end.y):(Q=s[1].x,a=s[1].y),c=0===t||2===t?Math.abs(o-Q):Math.abs(i-a),this.ctx.beginPath(),3===B?this.formatPath(n):this.formatPath(s.slice(0,2)),g=e<3?3*e:2*e,w=e<3?2*e:e,3===B&&(g=e,w=e),l=!0,c<=2*g?l=!1:c<=2*g+w?(U=c/(2*g+w),g*=U,w*=U):(u=Math.floor((c+w)/(g+w)),C=(c-u*g)/(u-1),w=(F=(c-(u+1)*g)/u)<=0||Math.abs(w-C)<Math.abs(w-F)?C:F),l&&(3===B?this.ctx.setLineDash([0,g+w]):this.ctx.setLineDash([g,w])),3===B?(this.ctx.lineCap="round",this.ctx.lineWidth=e):this.ctx.lineWidth=2*e+1.1,this.ctx.strokeStyle=ee(A),this.ctx.stroke(),this.ctx.setLineDash([]),2===B&&(B4(s[0])&&(h=s[3],d=s[0],this.ctx.beginPath(),this.formatPath([new Bz(h.end.x,h.end.y),new Bz(d.start.x,d.start.y)]),this.ctx.stroke()),B4(s[1])&&(h=s[1],d=s[2],this.ctx.beginPath(),this.formatPath([new Bz(h.end.x,h.end.y),new Bz(d.start.x,d.start.y)]),this.ctx.stroke())),this.ctx.restore(),[2]})})},e.prototype.render=function(A){return K(this,void 0,void 0,function(){var e;return m(this,function(t){switch(t.label){case 0:return this.options.backgroundColor&&(this.ctx.fillStyle=ee(this.options.backgroundColor),this.ctx.fillRect(this.options.x,this.options.y,this.options.width,this.options.height)),e=nn(A),[4,this.renderStack(e)];case 1:return t.sent(),this.applyEffects([]),[2,this.canvas]}})})},e}(nH),nE=function(A){return A instanceof r_||A instanceof rZ||A instanceof rW&&A.type!==rJ&&A.type!==rX},nI=function(A,e){switch(A){case 0:return B3(e);case 2:return[e.topLeftContentBox,e.topRightContentBox,e.bottomRightContentBox,e.bottomLeftContentBox];default:return B5(e)}},ny=function(A){switch(A){case 1:return"center";case 2:return"right";default:return"left"}},nK=["-apple-system","system-ui"],nm=function(A){return/iPhone OS 15_(0|1)/.test(window.navigator.userAgent)?A.filter(function(A){return -1===nK.indexOf(A)}):A},nL=function(A){function e(e,t){var r=A.call(this,e,t)||this;return r.canvas=t.canvas?t.canvas:document.createElement("canvas"),r.ctx=r.canvas.getContext("2d"),r.options=t,r.canvas.width=Math.floor(t.width*t.scale),r.canvas.height=Math.floor(t.height*t.scale),r.canvas.style.width=t.width+"px",r.canvas.style.height=t.height+"px",r.ctx.scale(r.options.scale,r.options.scale),r.ctx.translate(-t.x,-t.y),r.context.logger.debug("EXPERIMENTAL ForeignObject renderer initialized ("+t.width+"x"+t.height+" at "+t.x+","+t.y+") with scale "+t.scale),r}return I(e,A),e.prototype.render=function(A){return K(this,void 0,void 0,function(){var e;return m(this,function(t){switch(t.label){case 0:return[4,nb(rw(this.options.width*this.options.scale,this.options.height*this.options.scale,this.options.scale,this.options.scale,A))];case 1:return e=t.sent(),this.options.backgroundColor&&(this.ctx.fillStyle=ee(this.options.backgroundColor),this.ctx.fillRect(0,0,this.options.width*this.options.scale,this.options.height*this.options.scale)),this.ctx.drawImage(e,-this.options.x*this.options.scale,-this.options.y*this.options.scale),[2,this.canvas]}})})},e}(nH),nb=function(A){return new Promise(function(e,t){var r=new Image;r.onload=function(){e(r)},r.onerror=t,r.src="data:image/svg+xml;charset=utf-8,"+encodeURIComponent(new XMLSerializer().serializeToString(A))})},nv=function(){function A(A){var e=A.id,t=A.enabled;this.id=e,this.enabled=t,this.start=Date.now()}return A.prototype.debug=function(){for(var A=[],e=0;e<arguments.length;e++)A[e]=arguments[e];this.enabled&&("undefined"!=typeof window&&window.console&&"function"==typeof console.debug?console.debug.apply(console,L([this.id,this.getTime()+"ms"],A)):this.info.apply(this,A))},A.prototype.getTime=function(){return Date.now()-this.start},A.prototype.info=function(){for(var A=[],e=0;e<arguments.length;e++)A[e]=arguments[e];this.enabled&&"undefined"!=typeof window&&window.console&&"function"==typeof console.info&&console.info.apply(console,L([this.id,this.getTime()+"ms"],A))},A.prototype.warn=function(){for(var A=[],e=0;e<arguments.length;e++)A[e]=arguments[e];this.enabled&&("undefined"!=typeof window&&window.console&&"function"==typeof console.warn?console.warn.apply(console,L([this.id,this.getTime()+"ms"],A)):this.info.apply(this,A))},A.prototype.error=function(){for(var A=[],e=0;e<arguments.length;e++)A[e]=arguments[e];this.enabled&&("undefined"!=typeof window&&window.console&&"function"==typeof console.error?console.error.apply(console,L([this.id,this.getTime()+"ms"],A)):this.info.apply(this,A))},A.instances={},A}(),nD=function(){function A(e,t){var r;this.windowBounds=t,this.instanceName="#"+A.instanceCount++,this.logger=new nv({id:this.instanceName,enabled:e.logging}),this.cache=null!==(r=e.cache)&&void 0!==r?r:new BP(this,e)}return A.instanceCount=1,A}();"undefined"!=typeof window&&BN.setContext(window);var nx=function(A,e,t){var r=e.ownerDocument,B=r.documentElement?ei(A,getComputedStyle(r.documentElement).backgroundColor):eQ.TRANSPARENT,n=r.body?ei(A,getComputedStyle(r.body).backgroundColor):eQ.TRANSPARENT,s="string"==typeof t?ei(A,t):null===t?eQ.TRANSPARENT:4294967295;return e===r.documentElement?eA(B)?eA(n)?s:n:B:s};return function(A,e){var t;return void 0===e&&(e={}),t=e,K(void 0,void 0,void 0,function(){var e,r,B,n,s,o,i,Q,a,c,g,w,l,U,u,C,F,h,d,f,H,p,E,I,K,L,x,M,S,T,G,O,V,k,R,N,P;return m(this,function(m){switch(m.label){case 0:if(!A||"object"!=typeof A)return[2,Promise.reject("Invalid element provided as first argument")];if(!(e=A.ownerDocument))throw Error("Element is not attached to a Document");if(!(r=e.defaultView))throw Error("Document is not attached to a Window");if(B={allowTaint:null!==(H=t.allowTaint)&&void 0!==H&&H,imageTimeout:null!==(p=t.imageTimeout)&&void 0!==p?p:15e3,proxy:t.proxy,useCORS:null!==(E=t.useCORS)&&void 0!==E&&E},o=new nD(y({logging:null===(I=t.logging)||void 0===I||I,cache:t.cache},B),s=new b((n={windowWidth:null!==(K=t.windowWidth)&&void 0!==K?K:r.innerWidth,windowHeight:null!==(L=t.windowHeight)&&void 0!==L?L:r.innerHeight,scrollX:null!==(x=t.scrollX)&&void 0!==x?x:r.pageXOffset,scrollY:null!==(M=t.scrollY)&&void 0!==M?M:r.pageYOffset}).scrollX,n.scrollY,n.windowWidth,n.windowHeight)),i=null!==(S=t.foreignObjectRendering)&&void 0!==S&&S,Q={allowTaint:null!==(T=t.allowTaint)&&void 0!==T&&T,onclone:t.onclone,ignoreElements:t.ignoreElements,inlineImages:i,copyStyles:i},o.logger.debug("Starting document clone with size "+s.width+"x"+s.height+" scrolled to "+-s.left+","+-s.top),!(c=(a=new BK(o,A,Q)).clonedReferenceElement))return[2,Promise.reject("Unable to find element in cloned iframe")];return[4,a.toIFrame(e,s)];case 1:if(g=m.sent(),l=(w=Be(c)||"HTML"===c.tagName?D(c.ownerDocument):v(o,c)).width,U=w.height,u=w.left,C=w.top,F=nx(o,c,t.backgroundColor),h={canvas:t.canvas,backgroundColor:F,scale:null!==(O=null!==(G=t.scale)&&void 0!==G?G:r.devicePixelRatio)&&void 0!==O?O:1,x:(null!==(V=t.x)&&void 0!==V?V:0)+u,y:(null!==(k=t.y)&&void 0!==k?k:0)+C,width:null!==(R=t.width)&&void 0!==R?R:Math.ceil(l),height:null!==(N=t.height)&&void 0!==N?N:Math.ceil(U)},!i)return[3,3];return o.logger.debug("Document cloned, using foreign object rendering"),[4,new nL(o,h).render(c)];case 2:return d=m.sent(),[3,5];case 3:return o.logger.debug("Document cloned, element located at "+u+","+C+" with size "+l+"x"+U+" using computed rendering"),o.logger.debug("Starting DOM parsing"),f=r0(o,c),F===f.styles.backgroundColor&&(f.styles.backgroundColor=eQ.TRANSPARENT),o.logger.debug("Starting renderer for element at "+h.x+","+h.y+" with size "+h.width+"x"+h.height),[4,new np(o,h).render(f)];case 4:d=m.sent(),m.label=5;case 5:return(null===(P=t.removeContainer)||void 0===P||P)&&!BK.destroy(g)&&o.logger.error("Cannot detach cloned iframe as it is not in the DOM anymore"),o.logger.debug("Finished rendering"),[2,d]}})})}}()}}]);